"""Auto-generated element isotope data"""
# DO NOT EDIT - generated by construct_data.py

import warnings
from enum import StrEnum

from .dclass import ElementInfo


class Element(StrEnum):
    """Enumeration of element symbols."""

    Ac = "Ac"
    Ag = "Ag"
    Al = "Al"
    Am = "Am"
    Ar = "Ar"
    As = "As"
    At = "At"
    Au = "Au"
    B = "B"
    Ba = "Ba"
    Be = "Be"
    Bh = "Bh"
    Bi = "Bi"
    Bk = "Bk"
    Br = "Br"
    C = "C"
    Ca = "Ca"
    Cd = "Cd"
    Ce = "Ce"
    Cf = "Cf"
    Cl = "Cl"
    Cm = "Cm"
    Cn = "Cn"
    Co = "Co"
    Cr = "Cr"
    Cs = "Cs"
    Cu = "Cu"
    Db = "Db"
    Ds = "Ds"
    Dy = "Dy"
    Er = "Er"
    Es = "Es"
    Eu = "Eu"
    F = "F"
    Fe = "Fe"
    Fl = "Fl"
    Fm = "Fm"
    Fr = "Fr"
    Ga = "Ga"
    Gd = "Gd"
    Ge = "Ge"
    H = "H"
    He = "He"
    Hf = "Hf"
    Hg = "Hg"
    Ho = "Ho"
    Hs = "Hs"
    I = "I"
    In = "In"
    Ir = "Ir"
    K = "K"
    Kr = "Kr"
    La = "La"
    Li = "Li"
    Lr = "Lr"
    Lu = "Lu"
    Lv = "Lv"
    Mc = "Mc"
    Md = "Md"
    Mg = "Mg"
    Mn = "Mn"
    Mo = "Mo"
    Mt = "Mt"
    N = "N"
    Na = "Na"
    Nb = "Nb"
    Nd = "Nd"
    Ne = "Ne"
    Nh = "Nh"
    Ni = "Ni"
    No = "No"
    Np = "Np"
    O = "O"
    Og = "Og"
    Os = "Os"
    P = "P"
    Pa = "Pa"
    Pb = "Pb"
    Pd = "Pd"
    Pm = "Pm"
    Po = "Po"
    Pr = "Pr"
    Pt = "Pt"
    Pu = "Pu"
    Ra = "Ra"
    Rb = "Rb"
    Re = "Re"
    Rf = "Rf"
    Rg = "Rg"
    Rh = "Rh"
    Rn = "Rn"
    Ru = "Ru"
    S = "S"
    Sb = "Sb"
    Sc = "Sc"
    Se = "Se"
    Sg = "Sg"
    Si = "Si"
    Sm = "Sm"
    Sn = "Sn"
    Sr = "Sr"
    Ta = "Ta"
    Tb = "Tb"
    Tc = "Tc"
    Te = "Te"
    Th = "Th"
    Ti = "Ti"
    Tl = "Tl"
    Tm = "Tm"
    Ts = "Ts"
    U = "U"
    V = "V"
    W = "W"
    Xe = "Xe"
    Y = "Y"
    Yb = "Yb"
    Zn = "Zn"
    Zr = "Zr"

    @classmethod
    def from_str(cls, symbol: str) -> "Element":
        """Get Element enum from string"""
        return cls(symbol)


try:
    ISOTOPES: dict[tuple[Element, int | None], ElementInfo] = {
        (Element.H, None): ElementInfo(
            number=1,
            symbol=Element.H,
            mass_number=None,
            mass=1.00782503223,
            abundance=None,
            average_mass=1.0079407540557772,
            is_monoisotopic=None,
        ),
        (Element.H, 1): ElementInfo(
            number=1,
            symbol=Element.H,
            mass_number=1,
            mass=1.00782503223,
            abundance=0.999885,
            average_mass=1.00782503223,
            is_monoisotopic=True,
        ),
        (Element.H, 2): ElementInfo(
            number=1,
            symbol=Element.H,
            mass_number=2,
            mass=2.01410177812,
            abundance=0.000115,
            average_mass=2.01410177812,
            is_monoisotopic=False,
        ),
        (Element.H, 3): ElementInfo(
            number=1,
            symbol=Element.H,
            mass_number=3,
            mass=3.0160492779,
            abundance=0.0,
            average_mass=3.0160492779,
            is_monoisotopic=False,
        ),
        (Element.He, None): ElementInfo(
            number=2,
            symbol=Element.He,
            mass_number=None,
            mass=4.00260325413,
            abundance=None,
            average_mass=4.002601932120929,
            is_monoisotopic=None,
        ),
        (Element.He, 3): ElementInfo(
            number=2,
            symbol=Element.He,
            mass_number=3,
            mass=3.0160293201,
            abundance=1.34e-06,
            average_mass=3.0160293201,
            is_monoisotopic=False,
        ),
        (Element.He, 4): ElementInfo(
            number=2,
            symbol=Element.He,
            mass_number=4,
            mass=4.00260325413,
            abundance=0.99999866,
            average_mass=4.00260325413,
            is_monoisotopic=True,
        ),
        (Element.Li, None): ElementInfo(
            number=3,
            symbol=Element.Li,
            mass_number=None,
            mass=7.0160034366,
            abundance=None,
            average_mass=6.94003660291572,
            is_monoisotopic=None,
        ),
        (Element.Li, 6): ElementInfo(
            number=3,
            symbol=Element.Li,
            mass_number=6,
            mass=6.0151228874,
            abundance=0.0759,
            average_mass=6.0151228874,
            is_monoisotopic=False,
        ),
        (Element.Li, 7): ElementInfo(
            number=3,
            symbol=Element.Li,
            mass_number=7,
            mass=7.0160034366,
            abundance=0.9241,
            average_mass=7.0160034366,
            is_monoisotopic=True,
        ),
        (Element.Be, None): ElementInfo(
            number=4,
            symbol=Element.Be,
            mass_number=None,
            mass=9.012183065,
            abundance=None,
            average_mass=9.012183065,
            is_monoisotopic=None,
        ),
        (Element.Be, 9): ElementInfo(
            number=4,
            symbol=Element.Be,
            mass_number=9,
            mass=9.012183065,
            abundance=1.0,
            average_mass=9.012183065,
            is_monoisotopic=True,
        ),
        (Element.B, None): ElementInfo(
            number=5,
            symbol=Element.B,
            mass_number=None,
            mass=11.00930536,
            abundance=None,
            average_mass=10.811028046410001,
            is_monoisotopic=None,
        ),
        (Element.B, 10): ElementInfo(
            number=5,
            symbol=Element.B,
            mass_number=10,
            mass=10.01293695,
            abundance=0.199,
            average_mass=10.01293695,
            is_monoisotopic=False,
        ),
        (Element.B, 11): ElementInfo(
            number=5,
            symbol=Element.B,
            mass_number=11,
            mass=11.00930536,
            abundance=0.801,
            average_mass=11.00930536,
            is_monoisotopic=True,
        ),
        (Element.C, None): ElementInfo(
            number=6,
            symbol=Element.C,
            mass_number=None,
            mass=12.0,
            abundance=None,
            average_mass=12.010735896735248,
            is_monoisotopic=None,
        ),
        (Element.C, 12): ElementInfo(
            number=6,
            symbol=Element.C,
            mass_number=12,
            mass=12.0,
            abundance=0.9893,
            average_mass=12.0,
            is_monoisotopic=True,
        ),
        (Element.C, 13): ElementInfo(
            number=6,
            symbol=Element.C,
            mass_number=13,
            mass=13.00335483507,
            abundance=0.0107,
            average_mass=13.00335483507,
            is_monoisotopic=False,
        ),
        (Element.C, 14): ElementInfo(
            number=6,
            symbol=Element.C,
            mass_number=14,
            mass=14.0032419884,
            abundance=0.0,
            average_mass=14.0032419884,
            is_monoisotopic=False,
        ),
        (Element.N, None): ElementInfo(
            number=7,
            symbol=Element.N,
            mass_number=None,
            mass=14.00307400443,
            abundance=None,
            average_mass=14.006703211445798,
            is_monoisotopic=None,
        ),
        (Element.N, 14): ElementInfo(
            number=7,
            symbol=Element.N,
            mass_number=14,
            mass=14.00307400443,
            abundance=0.99636,
            average_mass=14.00307400443,
            is_monoisotopic=True,
        ),
        (Element.N, 15): ElementInfo(
            number=7,
            symbol=Element.N,
            mass_number=15,
            mass=15.00010889888,
            abundance=0.00364,
            average_mass=15.00010889888,
            is_monoisotopic=False,
        ),
        (Element.O, None): ElementInfo(
            number=8,
            symbol=Element.O,
            mass_number=None,
            mass=15.99491461957,
            abundance=None,
            average_mass=15.999404924318277,
            is_monoisotopic=None,
        ),
        (Element.O, 16): ElementInfo(
            number=8,
            symbol=Element.O,
            mass_number=16,
            mass=15.99491461957,
            abundance=0.99757,
            average_mass=15.99491461957,
            is_monoisotopic=True,
        ),
        (Element.O, 17): ElementInfo(
            number=8,
            symbol=Element.O,
            mass_number=17,
            mass=16.9991317565,
            abundance=0.00038,
            average_mass=16.9991317565,
            is_monoisotopic=False,
        ),
        (Element.O, 18): ElementInfo(
            number=8,
            symbol=Element.O,
            mass_number=18,
            mass=17.99915961286,
            abundance=0.00205,
            average_mass=17.99915961286,
            is_monoisotopic=False,
        ),
        (Element.F, None): ElementInfo(
            number=9,
            symbol=Element.F,
            mass_number=None,
            mass=18.99840316273,
            abundance=None,
            average_mass=18.99840316273,
            is_monoisotopic=None,
        ),
        (Element.F, 19): ElementInfo(
            number=9,
            symbol=Element.F,
            mass_number=19,
            mass=18.99840316273,
            abundance=1.0,
            average_mass=18.99840316273,
            is_monoisotopic=True,
        ),
        (Element.Ne, None): ElementInfo(
            number=10,
            symbol=Element.Ne,
            mass_number=None,
            mass=19.9924401762,
            abundance=None,
            average_mass=20.18004638052026,
            is_monoisotopic=None,
        ),
        (Element.Ne, 20): ElementInfo(
            number=10,
            symbol=Element.Ne,
            mass_number=20,
            mass=19.9924401762,
            abundance=0.9048,
            average_mass=19.9924401762,
            is_monoisotopic=True,
        ),
        (Element.Ne, 21): ElementInfo(
            number=10,
            symbol=Element.Ne,
            mass_number=21,
            mass=20.993846685,
            abundance=0.0027,
            average_mass=20.993846685,
            is_monoisotopic=False,
        ),
        (Element.Ne, 22): ElementInfo(
            number=10,
            symbol=Element.Ne,
            mass_number=22,
            mass=21.991385114,
            abundance=0.0925,
            average_mass=21.991385114,
            is_monoisotopic=False,
        ),
        (Element.Na, None): ElementInfo(
            number=11,
            symbol=Element.Na,
            mass_number=None,
            mass=22.989769282,
            abundance=None,
            average_mass=22.989769282,
            is_monoisotopic=None,
        ),
        (Element.Na, 23): ElementInfo(
            number=11,
            symbol=Element.Na,
            mass_number=23,
            mass=22.989769282,
            abundance=1.0,
            average_mass=22.989769282,
            is_monoisotopic=True,
        ),
        (Element.Mg, None): ElementInfo(
            number=12,
            symbol=Element.Mg,
            mass_number=None,
            mass=23.985041697,
            abundance=None,
            average_mass=24.3050516198371,
            is_monoisotopic=None,
        ),
        (Element.Mg, 24): ElementInfo(
            number=12,
            symbol=Element.Mg,
            mass_number=24,
            mass=23.985041697,
            abundance=0.7899,
            average_mass=23.985041697,
            is_monoisotopic=True,
        ),
        (Element.Mg, 25): ElementInfo(
            number=12,
            symbol=Element.Mg,
            mass_number=25,
            mass=24.985836976,
            abundance=0.1,
            average_mass=24.985836976,
            is_monoisotopic=False,
        ),
        (Element.Mg, 26): ElementInfo(
            number=12,
            symbol=Element.Mg,
            mass_number=26,
            mass=25.982592968,
            abundance=0.1101,
            average_mass=25.982592968,
            is_monoisotopic=False,
        ),
        (Element.Al, None): ElementInfo(
            number=13,
            symbol=Element.Al,
            mass_number=None,
            mass=26.98153853,
            abundance=None,
            average_mass=26.98153853,
            is_monoisotopic=None,
        ),
        (Element.Al, 27): ElementInfo(
            number=13,
            symbol=Element.Al,
            mass_number=27,
            mass=26.98153853,
            abundance=1.0,
            average_mass=26.98153853,
            is_monoisotopic=True,
        ),
        (Element.Si, None): ElementInfo(
            number=14,
            symbol=Element.Si,
            mass_number=None,
            mass=27.97692653465,
            abundance=None,
            average_mass=28.08549870570596,
            is_monoisotopic=None,
        ),
        (Element.Si, 28): ElementInfo(
            number=14,
            symbol=Element.Si,
            mass_number=28,
            mass=27.97692653465,
            abundance=0.92223,
            average_mass=27.97692653465,
            is_monoisotopic=True,
        ),
        (Element.Si, 29): ElementInfo(
            number=14,
            symbol=Element.Si,
            mass_number=29,
            mass=28.9764946649,
            abundance=0.04685,
            average_mass=28.9764946649,
            is_monoisotopic=False,
        ),
        (Element.Si, 30): ElementInfo(
            number=14,
            symbol=Element.Si,
            mass_number=30,
            mass=29.973770136,
            abundance=0.03092,
            average_mass=29.973770136,
            is_monoisotopic=False,
        ),
        (Element.P, None): ElementInfo(
            number=15,
            symbol=Element.P,
            mass_number=None,
            mass=30.97376199842,
            abundance=None,
            average_mass=30.97376199842,
            is_monoisotopic=None,
        ),
        (Element.P, 31): ElementInfo(
            number=15,
            symbol=Element.P,
            mass_number=31,
            mass=30.97376199842,
            abundance=1.0,
            average_mass=30.97376199842,
            is_monoisotopic=True,
        ),
        (Element.S, None): ElementInfo(
            number=16,
            symbol=Element.S,
            mass_number=None,
            mass=31.9720711744,
            abundance=None,
            average_mass=32.06478740612707,
            is_monoisotopic=None,
        ),
        (Element.S, 32): ElementInfo(
            number=16,
            symbol=Element.S,
            mass_number=32,
            mass=31.9720711744,
            abundance=0.9499,
            average_mass=31.9720711744,
            is_monoisotopic=True,
        ),
        (Element.S, 33): ElementInfo(
            number=16,
            symbol=Element.S,
            mass_number=33,
            mass=32.9714589098,
            abundance=0.0075,
            average_mass=32.9714589098,
            is_monoisotopic=False,
        ),
        (Element.S, 34): ElementInfo(
            number=16,
            symbol=Element.S,
            mass_number=34,
            mass=33.967867004,
            abundance=0.0425,
            average_mass=33.967867004,
            is_monoisotopic=False,
        ),
        (Element.S, 36): ElementInfo(
            number=16,
            symbol=Element.S,
            mass_number=36,
            mass=35.96708071,
            abundance=0.0001,
            average_mass=35.96708071,
            is_monoisotopic=False,
        ),
        (Element.Cl, None): ElementInfo(
            number=17,
            symbol=Element.Cl,
            mass_number=None,
            mass=34.968852682,
            abundance=None,
            average_mass=35.452937582608,
            is_monoisotopic=None,
        ),
        (Element.Cl, 35): ElementInfo(
            number=17,
            symbol=Element.Cl,
            mass_number=35,
            mass=34.968852682,
            abundance=0.7576,
            average_mass=34.968852682,
            is_monoisotopic=True,
        ),
        (Element.Cl, 37): ElementInfo(
            number=17,
            symbol=Element.Cl,
            mass_number=37,
            mass=36.965902602,
            abundance=0.2424,
            average_mass=36.965902602,
            is_monoisotopic=False,
        ),
        (Element.Ar, None): ElementInfo(
            number=18,
            symbol=Element.Ar,
            mass_number=None,
            mass=39.9623831237,
            abundance=None,
            average_mass=39.947798563582005,
            is_monoisotopic=None,
        ),
        (Element.Ar, 36): ElementInfo(
            number=18,
            symbol=Element.Ar,
            mass_number=36,
            mass=35.967545105,
            abundance=0.003336,
            average_mass=35.967545105,
            is_monoisotopic=False,
        ),
        (Element.Ar, 38): ElementInfo(
            number=18,
            symbol=Element.Ar,
            mass_number=38,
            mass=37.96273211,
            abundance=0.000629,
            average_mass=37.96273211,
            is_monoisotopic=False,
        ),
        (Element.Ar, 40): ElementInfo(
            number=18,
            symbol=Element.Ar,
            mass_number=40,
            mass=39.9623831237,
            abundance=0.996035,
            average_mass=39.9623831237,
            is_monoisotopic=True,
        ),
        (Element.K, None): ElementInfo(
            number=19,
            symbol=Element.K,
            mass_number=None,
            mass=38.9637064864,
            abundance=None,
            average_mass=39.098300910086,
            is_monoisotopic=None,
        ),
        (Element.K, 39): ElementInfo(
            number=19,
            symbol=Element.K,
            mass_number=39,
            mass=38.9637064864,
            abundance=0.932581,
            average_mass=38.9637064864,
            is_monoisotopic=True,
        ),
        (Element.K, 40): ElementInfo(
            number=19,
            symbol=Element.K,
            mass_number=40,
            mass=39.963998166,
            abundance=0.000117,
            average_mass=39.963998166,
            is_monoisotopic=False,
        ),
        (Element.K, 41): ElementInfo(
            number=19,
            symbol=Element.K,
            mass_number=41,
            mass=40.9618252579,
            abundance=0.067302,
            average_mass=40.9618252579,
            is_monoisotopic=False,
        ),
        (Element.Ca, None): ElementInfo(
            number=20,
            symbol=Element.Ca,
            mass_number=None,
            mass=39.962590863,
            abundance=None,
            average_mass=40.078022511017735,
            is_monoisotopic=None,
        ),
        (Element.Ca, 40): ElementInfo(
            number=20,
            symbol=Element.Ca,
            mass_number=40,
            mass=39.962590863,
            abundance=0.96941,
            average_mass=39.962590863,
            is_monoisotopic=True,
        ),
        (Element.Ca, 42): ElementInfo(
            number=20,
            symbol=Element.Ca,
            mass_number=42,
            mass=41.95861783,
            abundance=0.00647,
            average_mass=41.95861783,
            is_monoisotopic=False,
        ),
        (Element.Ca, 43): ElementInfo(
            number=20,
            symbol=Element.Ca,
            mass_number=43,
            mass=42.95876644,
            abundance=0.00135,
            average_mass=42.95876644,
            is_monoisotopic=False,
        ),
        (Element.Ca, 44): ElementInfo(
            number=20,
            symbol=Element.Ca,
            mass_number=44,
            mass=43.95548156,
            abundance=0.02086,
            average_mass=43.95548156,
            is_monoisotopic=False,
        ),
        (Element.Ca, 46): ElementInfo(
            number=20,
            symbol=Element.Ca,
            mass_number=46,
            mass=45.953689,
            abundance=4e-05,
            average_mass=45.953689,
            is_monoisotopic=False,
        ),
        (Element.Ca, 48): ElementInfo(
            number=20,
            symbol=Element.Ca,
            mass_number=48,
            mass=47.95252276,
            abundance=0.00187,
            average_mass=47.95252276,
            is_monoisotopic=False,
        ),
        (Element.Sc, None): ElementInfo(
            number=21,
            symbol=Element.Sc,
            mass_number=None,
            mass=44.95590828,
            abundance=None,
            average_mass=44.95590828,
            is_monoisotopic=None,
        ),
        (Element.Sc, 45): ElementInfo(
            number=21,
            symbol=Element.Sc,
            mass_number=45,
            mass=44.95590828,
            abundance=1.0,
            average_mass=44.95590828,
            is_monoisotopic=True,
        ),
        (Element.Ti, None): ElementInfo(
            number=22,
            symbol=Element.Ti,
            mass_number=None,
            mass=47.94794198,
            abundance=None,
            average_mass=47.866744962722,
            is_monoisotopic=None,
        ),
        (Element.Ti, 46): ElementInfo(
            number=22,
            symbol=Element.Ti,
            mass_number=46,
            mass=45.95262772,
            abundance=0.0825,
            average_mass=45.95262772,
            is_monoisotopic=False,
        ),
        (Element.Ti, 47): ElementInfo(
            number=22,
            symbol=Element.Ti,
            mass_number=47,
            mass=46.95175879,
            abundance=0.0744,
            average_mass=46.95175879,
            is_monoisotopic=False,
        ),
        (Element.Ti, 48): ElementInfo(
            number=22,
            symbol=Element.Ti,
            mass_number=48,
            mass=47.94794198,
            abundance=0.7372,
            average_mass=47.94794198,
            is_monoisotopic=True,
        ),
        (Element.Ti, 49): ElementInfo(
            number=22,
            symbol=Element.Ti,
            mass_number=49,
            mass=48.94786568,
            abundance=0.0541,
            average_mass=48.94786568,
            is_monoisotopic=False,
        ),
        (Element.Ti, 50): ElementInfo(
            number=22,
            symbol=Element.Ti,
            mass_number=50,
            mass=49.94478689,
            abundance=0.0518,
            average_mass=49.94478689,
            is_monoisotopic=False,
        ),
        (Element.V, None): ElementInfo(
            number=23,
            symbol=Element.V,
            mass_number=None,
            mass=50.94395704,
            abundance=None,
            average_mass=50.941465037425004,
            is_monoisotopic=None,
        ),
        (Element.V, 50): ElementInfo(
            number=23,
            symbol=Element.V,
            mass_number=50,
            mass=49.94715601,
            abundance=0.0025,
            average_mass=49.94715601,
            is_monoisotopic=False,
        ),
        (Element.V, 51): ElementInfo(
            number=23,
            symbol=Element.V,
            mass_number=51,
            mass=50.94395704,
            abundance=0.9975,
            average_mass=50.94395704,
            is_monoisotopic=True,
        ),
        (Element.Cr, None): ElementInfo(
            number=24,
            symbol=Element.Cr,
            mass_number=None,
            mass=51.94050623,
            abundance=None,
            average_mass=51.9961317554337,
            is_monoisotopic=None,
        ),
        (Element.Cr, 50): ElementInfo(
            number=24,
            symbol=Element.Cr,
            mass_number=50,
            mass=49.94604183,
            abundance=0.04345,
            average_mass=49.94604183,
            is_monoisotopic=False,
        ),
        (Element.Cr, 52): ElementInfo(
            number=24,
            symbol=Element.Cr,
            mass_number=52,
            mass=51.94050623,
            abundance=0.83789,
            average_mass=51.94050623,
            is_monoisotopic=True,
        ),
        (Element.Cr, 53): ElementInfo(
            number=24,
            symbol=Element.Cr,
            mass_number=53,
            mass=52.94064815,
            abundance=0.09501,
            average_mass=52.94064815,
            is_monoisotopic=False,
        ),
        (Element.Cr, 54): ElementInfo(
            number=24,
            symbol=Element.Cr,
            mass_number=54,
            mass=53.93887916,
            abundance=0.02365,
            average_mass=53.93887916,
            is_monoisotopic=False,
        ),
        (Element.Mn, None): ElementInfo(
            number=25,
            symbol=Element.Mn,
            mass_number=None,
            mass=54.93804391,
            abundance=None,
            average_mass=54.93804391,
            is_monoisotopic=None,
        ),
        (Element.Mn, 55): ElementInfo(
            number=25,
            symbol=Element.Mn,
            mass_number=55,
            mass=54.93804391,
            abundance=1.0,
            average_mass=54.93804391,
            is_monoisotopic=True,
        ),
        (Element.Fe, None): ElementInfo(
            number=26,
            symbol=Element.Fe,
            mass_number=None,
            mass=55.93493633,
            abundance=None,
            average_mass=55.845144433865904,
            is_monoisotopic=None,
        ),
        (Element.Fe, 54): ElementInfo(
            number=26,
            symbol=Element.Fe,
            mass_number=54,
            mass=53.93960899,
            abundance=0.05845,
            average_mass=53.93960899,
            is_monoisotopic=False,
        ),
        (Element.Fe, 56): ElementInfo(
            number=26,
            symbol=Element.Fe,
            mass_number=56,
            mass=55.93493633,
            abundance=0.91754,
            average_mass=55.93493633,
            is_monoisotopic=True,
        ),
        (Element.Fe, 57): ElementInfo(
            number=26,
            symbol=Element.Fe,
            mass_number=57,
            mass=56.93539284,
            abundance=0.02119,
            average_mass=56.93539284,
            is_monoisotopic=False,
        ),
        (Element.Fe, 58): ElementInfo(
            number=26,
            symbol=Element.Fe,
            mass_number=58,
            mass=57.93327443,
            abundance=0.00282,
            average_mass=57.93327443,
            is_monoisotopic=False,
        ),
        (Element.Co, None): ElementInfo(
            number=27,
            symbol=Element.Co,
            mass_number=None,
            mass=58.93319429,
            abundance=None,
            average_mass=58.93319429,
            is_monoisotopic=None,
        ),
        (Element.Co, 59): ElementInfo(
            number=27,
            symbol=Element.Co,
            mass_number=59,
            mass=58.93319429,
            abundance=1.0,
            average_mass=58.93319429,
            is_monoisotopic=True,
        ),
        (Element.Ni, None): ElementInfo(
            number=28,
            symbol=Element.Ni,
            mass_number=None,
            mass=57.93534241,
            abundance=None,
            average_mass=58.69334710994765,
            is_monoisotopic=None,
        ),
        (Element.Ni, 58): ElementInfo(
            number=28,
            symbol=Element.Ni,
            mass_number=58,
            mass=57.93534241,
            abundance=0.68077,
            average_mass=57.93534241,
            is_monoisotopic=True,
        ),
        (Element.Ni, 60): ElementInfo(
            number=28,
            symbol=Element.Ni,
            mass_number=60,
            mass=59.93078588,
            abundance=0.26223,
            average_mass=59.93078588,
            is_monoisotopic=False,
        ),
        (Element.Ni, 61): ElementInfo(
            number=28,
            symbol=Element.Ni,
            mass_number=61,
            mass=60.93105557,
            abundance=0.011399,
            average_mass=60.93105557,
            is_monoisotopic=False,
        ),
        (Element.Ni, 62): ElementInfo(
            number=28,
            symbol=Element.Ni,
            mass_number=62,
            mass=61.92834537,
            abundance=0.036346,
            average_mass=61.92834537,
            is_monoisotopic=False,
        ),
        (Element.Ni, 64): ElementInfo(
            number=28,
            symbol=Element.Ni,
            mass_number=64,
            mass=63.92796682,
            abundance=0.009255,
            average_mass=63.92796682,
            is_monoisotopic=False,
        ),
        (Element.Cu, None): ElementInfo(
            number=29,
            symbol=Element.Cu,
            mass_number=None,
            mass=62.92959772,
            abundance=None,
            average_mass=63.54603994583,
            is_monoisotopic=None,
        ),
        (Element.Cu, 63): ElementInfo(
            number=29,
            symbol=Element.Cu,
            mass_number=63,
            mass=62.92959772,
            abundance=0.6915,
            average_mass=62.92959772,
            is_monoisotopic=True,
        ),
        (Element.Cu, 65): ElementInfo(
            number=29,
            symbol=Element.Cu,
            mass_number=65,
            mass=64.9277897,
            abundance=0.3085,
            average_mass=64.9277897,
            is_monoisotopic=False,
        ),
        (Element.Zn, None): ElementInfo(
            number=30,
            symbol=Element.Zn,
            mass_number=None,
            mass=63.92914201,
            abundance=None,
            average_mass=65.37778252952499,
            is_monoisotopic=None,
        ),
        (Element.Zn, 64): ElementInfo(
            number=30,
            symbol=Element.Zn,
            mass_number=64,
            mass=63.92914201,
            abundance=0.4917,
            average_mass=63.92914201,
            is_monoisotopic=True,
        ),
        (Element.Zn, 66): ElementInfo(
            number=30,
            symbol=Element.Zn,
            mass_number=66,
            mass=65.92603381,
            abundance=0.2773,
            average_mass=65.92603381,
            is_monoisotopic=False,
        ),
        (Element.Zn, 67): ElementInfo(
            number=30,
            symbol=Element.Zn,
            mass_number=67,
            mass=66.92712775,
            abundance=0.0404,
            average_mass=66.92712775,
            is_monoisotopic=False,
        ),
        (Element.Zn, 68): ElementInfo(
            number=30,
            symbol=Element.Zn,
            mass_number=68,
            mass=67.92484455,
            abundance=0.1845,
            average_mass=67.92484455,
            is_monoisotopic=False,
        ),
        (Element.Zn, 70): ElementInfo(
            number=30,
            symbol=Element.Zn,
            mass_number=70,
            mass=69.9253192,
            abundance=0.0061,
            average_mass=69.9253192,
            is_monoisotopic=False,
        ),
        (Element.Ga, None): ElementInfo(
            number=31,
            symbol=Element.Ga,
            mass_number=None,
            mass=68.9255735,
            abundance=None,
            average_mass=69.7230660725936,
            is_monoisotopic=None,
        ),
        (Element.Ga, 69): ElementInfo(
            number=31,
            symbol=Element.Ga,
            mass_number=69,
            mass=68.9255735,
            abundance=0.60108,
            average_mass=68.9255735,
            is_monoisotopic=True,
        ),
        (Element.Ga, 71): ElementInfo(
            number=31,
            symbol=Element.Ga,
            mass_number=71,
            mass=70.92470258,
            abundance=0.39892,
            average_mass=70.92470258,
            is_monoisotopic=False,
        ),
        (Element.Ge, None): ElementInfo(
            number=32,
            symbol=Element.Ge,
            mass_number=None,
            mass=73.921177761,
            abundance=None,
            average_mass=72.6275501646868,
            is_monoisotopic=None,
        ),
        (Element.Ge, 70): ElementInfo(
            number=32,
            symbol=Element.Ge,
            mass_number=70,
            mass=69.92424875,
            abundance=0.2057,
            average_mass=69.92424875,
            is_monoisotopic=False,
        ),
        (Element.Ge, 72): ElementInfo(
            number=32,
            symbol=Element.Ge,
            mass_number=72,
            mass=71.922075826,
            abundance=0.2745,
            average_mass=71.922075826,
            is_monoisotopic=False,
        ),
        (Element.Ge, 73): ElementInfo(
            number=32,
            symbol=Element.Ge,
            mass_number=73,
            mass=72.923458956,
            abundance=0.0775,
            average_mass=72.923458956,
            is_monoisotopic=False,
        ),
        (Element.Ge, 74): ElementInfo(
            number=32,
            symbol=Element.Ge,
            mass_number=74,
            mass=73.921177761,
            abundance=0.365,
            average_mass=73.921177761,
            is_monoisotopic=True,
        ),
        (Element.Ge, 76): ElementInfo(
            number=32,
            symbol=Element.Ge,
            mass_number=76,
            mass=75.921402726,
            abundance=0.0773,
            average_mass=75.921402726,
            is_monoisotopic=False,
        ),
        (Element.As, None): ElementInfo(
            number=33,
            symbol=Element.As,
            mass_number=None,
            mass=74.92159457,
            abundance=None,
            average_mass=74.92159457,
            is_monoisotopic=None,
        ),
        (Element.As, 75): ElementInfo(
            number=33,
            symbol=Element.As,
            mass_number=75,
            mass=74.92159457,
            abundance=1.0,
            average_mass=74.92159457,
            is_monoisotopic=True,
        ),
        (Element.Se, None): ElementInfo(
            number=34,
            symbol=Element.Se,
            mass_number=None,
            mass=79.9165218,
            abundance=None,
            average_mass=78.95938855701361,
            is_monoisotopic=None,
        ),
        (Element.Se, 74): ElementInfo(
            number=34,
            symbol=Element.Se,
            mass_number=74,
            mass=73.922475934,
            abundance=0.0089,
            average_mass=73.922475934,
            is_monoisotopic=False,
        ),
        (Element.Se, 76): ElementInfo(
            number=34,
            symbol=Element.Se,
            mass_number=76,
            mass=75.919213704,
            abundance=0.0937,
            average_mass=75.919213704,
            is_monoisotopic=False,
        ),
        (Element.Se, 77): ElementInfo(
            number=34,
            symbol=Element.Se,
            mass_number=77,
            mass=76.919914154,
            abundance=0.0763,
            average_mass=76.919914154,
            is_monoisotopic=False,
        ),
        (Element.Se, 78): ElementInfo(
            number=34,
            symbol=Element.Se,
            mass_number=78,
            mass=77.91730928,
            abundance=0.2377,
            average_mass=77.91730928,
            is_monoisotopic=False,
        ),
        (Element.Se, 80): ElementInfo(
            number=34,
            symbol=Element.Se,
            mass_number=80,
            mass=79.9165218,
            abundance=0.4961,
            average_mass=79.9165218,
            is_monoisotopic=True,
        ),
        (Element.Se, 82): ElementInfo(
            number=34,
            symbol=Element.Se,
            mass_number=82,
            mass=81.9166995,
            abundance=0.0873,
            average_mass=81.9166995,
            is_monoisotopic=False,
        ),
        (Element.Br, None): ElementInfo(
            number=35,
            symbol=Element.Br,
            mass_number=None,
            mass=78.9183376,
            abundance=None,
            average_mass=79.90352778050999,
            is_monoisotopic=None,
        ),
        (Element.Br, 79): ElementInfo(
            number=35,
            symbol=Element.Br,
            mass_number=79,
            mass=78.9183376,
            abundance=0.5069,
            average_mass=78.9183376,
            is_monoisotopic=True,
        ),
        (Element.Br, 81): ElementInfo(
            number=35,
            symbol=Element.Br,
            mass_number=81,
            mass=80.9162897,
            abundance=0.4931,
            average_mass=80.9162897,
            is_monoisotopic=False,
        ),
        (Element.Kr, None): ElementInfo(
            number=36,
            symbol=Element.Kr,
            mass_number=None,
            mass=83.9114977282,
            abundance=None,
            average_mass=83.7979999953261,
            is_monoisotopic=None,
        ),
        (Element.Kr, 78): ElementInfo(
            number=36,
            symbol=Element.Kr,
            mass_number=78,
            mass=77.92036494,
            abundance=0.00355,
            average_mass=77.92036494,
            is_monoisotopic=False,
        ),
        (Element.Kr, 80): ElementInfo(
            number=36,
            symbol=Element.Kr,
            mass_number=80,
            mass=79.91637808,
            abundance=0.02286,
            average_mass=79.91637808,
            is_monoisotopic=False,
        ),
        (Element.Kr, 82): ElementInfo(
            number=36,
            symbol=Element.Kr,
            mass_number=82,
            mass=81.91348273,
            abundance=0.11593,
            average_mass=81.91348273,
            is_monoisotopic=False,
        ),
        (Element.Kr, 83): ElementInfo(
            number=36,
            symbol=Element.Kr,
            mass_number=83,
            mass=82.91412716,
            abundance=0.115,
            average_mass=82.91412716,
            is_monoisotopic=False,
        ),
        (Element.Kr, 84): ElementInfo(
            number=36,
            symbol=Element.Kr,
            mass_number=84,
            mass=83.9114977282,
            abundance=0.56987,
            average_mass=83.9114977282,
            is_monoisotopic=True,
        ),
        (Element.Kr, 86): ElementInfo(
            number=36,
            symbol=Element.Kr,
            mass_number=86,
            mass=85.9106106269,
            abundance=0.17279,
            average_mass=85.9106106269,
            is_monoisotopic=False,
        ),
        (Element.Rb, None): ElementInfo(
            number=37,
            symbol=Element.Rb,
            mass_number=None,
            mass=84.9117897379,
            abundance=None,
            average_mass=85.46766359561973,
            is_monoisotopic=None,
        ),
        (Element.Rb, 85): ElementInfo(
            number=37,
            symbol=Element.Rb,
            mass_number=85,
            mass=84.9117897379,
            abundance=0.7217,
            average_mass=84.9117897379,
            is_monoisotopic=True,
        ),
        (Element.Rb, 87): ElementInfo(
            number=37,
            symbol=Element.Rb,
            mass_number=87,
            mass=86.909180531,
            abundance=0.2783,
            average_mass=86.909180531,
            is_monoisotopic=False,
        ),
        (Element.Sr, None): ElementInfo(
            number=38,
            symbol=Element.Sr,
            mass_number=None,
            mass=87.9056125,
            abundance=None,
            average_mass=87.61664446962,
            is_monoisotopic=None,
        ),
        (Element.Sr, 84): ElementInfo(
            number=38,
            symbol=Element.Sr,
            mass_number=84,
            mass=83.9134191,
            abundance=0.0056,
            average_mass=83.9134191,
            is_monoisotopic=False,
        ),
        (Element.Sr, 86): ElementInfo(
            number=38,
            symbol=Element.Sr,
            mass_number=86,
            mass=85.9092606,
            abundance=0.0986,
            average_mass=85.9092606,
            is_monoisotopic=False,
        ),
        (Element.Sr, 87): ElementInfo(
            number=38,
            symbol=Element.Sr,
            mass_number=87,
            mass=86.9088775,
            abundance=0.07,
            average_mass=86.9088775,
            is_monoisotopic=False,
        ),
        (Element.Sr, 88): ElementInfo(
            number=38,
            symbol=Element.Sr,
            mass_number=88,
            mass=87.9056125,
            abundance=0.8258,
            average_mass=87.9056125,
            is_monoisotopic=True,
        ),
        (Element.Y, None): ElementInfo(
            number=39,
            symbol=Element.Y,
            mass_number=None,
            mass=88.9058403,
            abundance=None,
            average_mass=88.9058403,
            is_monoisotopic=None,
        ),
        (Element.Y, 89): ElementInfo(
            number=39,
            symbol=Element.Y,
            mass_number=89,
            mass=88.9058403,
            abundance=1.0,
            average_mass=88.9058403,
            is_monoisotopic=True,
        ),
        (Element.Zr, None): ElementInfo(
            number=40,
            symbol=Element.Zr,
            mass_number=None,
            mass=89.9046977,
            abundance=None,
            average_mass=91.22364159706,
            is_monoisotopic=None,
        ),
        (Element.Zr, 90): ElementInfo(
            number=40,
            symbol=Element.Zr,
            mass_number=90,
            mass=89.9046977,
            abundance=0.5145,
            average_mass=89.9046977,
            is_monoisotopic=True,
        ),
        (Element.Zr, 91): ElementInfo(
            number=40,
            symbol=Element.Zr,
            mass_number=91,
            mass=90.9056396,
            abundance=0.1122,
            average_mass=90.9056396,
            is_monoisotopic=False,
        ),
        (Element.Zr, 92): ElementInfo(
            number=40,
            symbol=Element.Zr,
            mass_number=92,
            mass=91.9050347,
            abundance=0.1715,
            average_mass=91.9050347,
            is_monoisotopic=False,
        ),
        (Element.Zr, 94): ElementInfo(
            number=40,
            symbol=Element.Zr,
            mass_number=94,
            mass=93.9063108,
            abundance=0.1738,
            average_mass=93.9063108,
            is_monoisotopic=False,
        ),
        (Element.Zr, 96): ElementInfo(
            number=40,
            symbol=Element.Zr,
            mass_number=96,
            mass=95.9082714,
            abundance=0.028,
            average_mass=95.9082714,
            is_monoisotopic=False,
        ),
        (Element.Nb, None): ElementInfo(
            number=41,
            symbol=Element.Nb,
            mass_number=None,
            mass=92.906373,
            abundance=None,
            average_mass=92.906373,
            is_monoisotopic=None,
        ),
        (Element.Nb, 93): ElementInfo(
            number=41,
            symbol=Element.Nb,
            mass_number=93,
            mass=92.906373,
            abundance=1.0,
            average_mass=92.906373,
            is_monoisotopic=True,
        ),
        (Element.Mo, None): ElementInfo(
            number=42,
            symbol=Element.Mo,
            mass_number=None,
            mass=97.90540482,
            abundance=None,
            average_mass=95.95978854118802,
            is_monoisotopic=None,
        ),
        (Element.Mo, 92): ElementInfo(
            number=42,
            symbol=Element.Mo,
            mass_number=92,
            mass=91.90680796,
            abundance=0.1453,
            average_mass=91.90680796,
            is_monoisotopic=False,
        ),
        (Element.Mo, 94): ElementInfo(
            number=42,
            symbol=Element.Mo,
            mass_number=94,
            mass=93.9050849,
            abundance=0.0915,
            average_mass=93.9050849,
            is_monoisotopic=False,
        ),
        (Element.Mo, 95): ElementInfo(
            number=42,
            symbol=Element.Mo,
            mass_number=95,
            mass=94.90583877,
            abundance=0.1584,
            average_mass=94.90583877,
            is_monoisotopic=False,
        ),
        (Element.Mo, 96): ElementInfo(
            number=42,
            symbol=Element.Mo,
            mass_number=96,
            mass=95.90467612,
            abundance=0.1667,
            average_mass=95.90467612,
            is_monoisotopic=False,
        ),
        (Element.Mo, 97): ElementInfo(
            number=42,
            symbol=Element.Mo,
            mass_number=97,
            mass=96.90601812,
            abundance=0.096,
            average_mass=96.90601812,
            is_monoisotopic=False,
        ),
        (Element.Mo, 98): ElementInfo(
            number=42,
            symbol=Element.Mo,
            mass_number=98,
            mass=97.90540482,
            abundance=0.2439,
            average_mass=97.90540482,
            is_monoisotopic=True,
        ),
        (Element.Mo, 100): ElementInfo(
            number=42,
            symbol=Element.Mo,
            mass_number=100,
            mass=99.9074718,
            abundance=0.0982,
            average_mass=99.9074718,
            is_monoisotopic=False,
        ),
        (Element.Tc, None): ElementInfo(
            number=43,
            symbol=Element.Tc,
            mass_number=None,
            mass=96.9063667,
            abundance=None,
            average_mass=96.9063667,
            is_monoisotopic=None,
        ),
        (Element.Tc, 97): ElementInfo(
            number=43,
            symbol=Element.Tc,
            mass_number=97,
            mass=96.9063667,
            abundance=0.0,
            average_mass=96.9063667,
            is_monoisotopic=True,
        ),
        (Element.Tc, 98): ElementInfo(
            number=43,
            symbol=Element.Tc,
            mass_number=98,
            mass=97.9072124,
            abundance=0.0,
            average_mass=97.9072124,
            is_monoisotopic=False,
        ),
        (Element.Tc, 99): ElementInfo(
            number=43,
            symbol=Element.Tc,
            mass_number=99,
            mass=98.9062508,
            abundance=0.0,
            average_mass=98.9062508,
            is_monoisotopic=False,
        ),
        (Element.Ru, None): ElementInfo(
            number=44,
            symbol=Element.Ru,
            mass_number=None,
            mass=101.9043441,
            abundance=None,
            average_mass=101.06494013916,
            is_monoisotopic=None,
        ),
        (Element.Ru, 96): ElementInfo(
            number=44,
            symbol=Element.Ru,
            mass_number=96,
            mass=95.90759025,
            abundance=0.0554,
            average_mass=95.90759025,
            is_monoisotopic=False,
        ),
        (Element.Ru, 98): ElementInfo(
            number=44,
            symbol=Element.Ru,
            mass_number=98,
            mass=97.9052868,
            abundance=0.0187,
            average_mass=97.9052868,
            is_monoisotopic=False,
        ),
        (Element.Ru, 99): ElementInfo(
            number=44,
            symbol=Element.Ru,
            mass_number=99,
            mass=98.9059341,
            abundance=0.1276,
            average_mass=98.9059341,
            is_monoisotopic=False,
        ),
        (Element.Ru, 100): ElementInfo(
            number=44,
            symbol=Element.Ru,
            mass_number=100,
            mass=99.9042143,
            abundance=0.126,
            average_mass=99.9042143,
            is_monoisotopic=False,
        ),
        (Element.Ru, 101): ElementInfo(
            number=44,
            symbol=Element.Ru,
            mass_number=101,
            mass=100.9055769,
            abundance=0.1706,
            average_mass=100.9055769,
            is_monoisotopic=False,
        ),
        (Element.Ru, 102): ElementInfo(
            number=44,
            symbol=Element.Ru,
            mass_number=102,
            mass=101.9043441,
            abundance=0.3155,
            average_mass=101.9043441,
            is_monoisotopic=True,
        ),
        (Element.Ru, 104): ElementInfo(
            number=44,
            symbol=Element.Ru,
            mass_number=104,
            mass=103.9054275,
            abundance=0.1862,
            average_mass=103.9054275,
            is_monoisotopic=False,
        ),
        (Element.Rh, None): ElementInfo(
            number=45,
            symbol=Element.Rh,
            mass_number=None,
            mass=102.905498,
            abundance=None,
            average_mass=102.905498,
            is_monoisotopic=None,
        ),
        (Element.Rh, 103): ElementInfo(
            number=45,
            symbol=Element.Rh,
            mass_number=103,
            mass=102.905498,
            abundance=1.0,
            average_mass=102.905498,
            is_monoisotopic=True,
        ),
        (Element.Pd, None): ElementInfo(
            number=46,
            symbol=Element.Pd,
            mass_number=None,
            mass=105.9034804,
            abundance=None,
            average_mass=106.41532750734,
            is_monoisotopic=None,
        ),
        (Element.Pd, 102): ElementInfo(
            number=46,
            symbol=Element.Pd,
            mass_number=102,
            mass=101.9056022,
            abundance=0.0102,
            average_mass=101.9056022,
            is_monoisotopic=False,
        ),
        (Element.Pd, 104): ElementInfo(
            number=46,
            symbol=Element.Pd,
            mass_number=104,
            mass=103.9040305,
            abundance=0.1114,
            average_mass=103.9040305,
            is_monoisotopic=False,
        ),
        (Element.Pd, 105): ElementInfo(
            number=46,
            symbol=Element.Pd,
            mass_number=105,
            mass=104.9050796,
            abundance=0.2233,
            average_mass=104.9050796,
            is_monoisotopic=False,
        ),
        (Element.Pd, 106): ElementInfo(
            number=46,
            symbol=Element.Pd,
            mass_number=106,
            mass=105.9034804,
            abundance=0.2733,
            average_mass=105.9034804,
            is_monoisotopic=True,
        ),
        (Element.Pd, 108): ElementInfo(
            number=46,
            symbol=Element.Pd,
            mass_number=108,
            mass=107.9038916,
            abundance=0.2646,
            average_mass=107.9038916,
            is_monoisotopic=False,
        ),
        (Element.Pd, 110): ElementInfo(
            number=46,
            symbol=Element.Pd,
            mass_number=110,
            mass=109.9051722,
            abundance=0.1172,
            average_mass=109.9051722,
            is_monoisotopic=False,
        ),
        (Element.Ag, None): ElementInfo(
            number=47,
            symbol=Element.Ag,
            mass_number=None,
            mass=106.9050916,
            abundance=None,
            average_mass=107.868149634557,
            is_monoisotopic=None,
        ),
        (Element.Ag, 107): ElementInfo(
            number=47,
            symbol=Element.Ag,
            mass_number=107,
            mass=106.9050916,
            abundance=0.51839,
            average_mass=106.9050916,
            is_monoisotopic=True,
        ),
        (Element.Ag, 109): ElementInfo(
            number=47,
            symbol=Element.Ag,
            mass_number=109,
            mass=108.9047553,
            abundance=0.48161,
            average_mass=108.9047553,
            is_monoisotopic=False,
        ),
        (Element.Cd, None): ElementInfo(
            number=48,
            symbol=Element.Cd,
            mass_number=None,
            mass=113.90336509,
            abundance=None,
            average_mass=112.41155781826801,
            is_monoisotopic=None,
        ),
        (Element.Cd, 106): ElementInfo(
            number=48,
            symbol=Element.Cd,
            mass_number=106,
            mass=105.9064599,
            abundance=0.0125,
            average_mass=105.9064599,
            is_monoisotopic=False,
        ),
        (Element.Cd, 108): ElementInfo(
            number=48,
            symbol=Element.Cd,
            mass_number=108,
            mass=107.9041834,
            abundance=0.0089,
            average_mass=107.9041834,
            is_monoisotopic=False,
        ),
        (Element.Cd, 110): ElementInfo(
            number=48,
            symbol=Element.Cd,
            mass_number=110,
            mass=109.90300661,
            abundance=0.1249,
            average_mass=109.90300661,
            is_monoisotopic=False,
        ),
        (Element.Cd, 111): ElementInfo(
            number=48,
            symbol=Element.Cd,
            mass_number=111,
            mass=110.90418287,
            abundance=0.128,
            average_mass=110.90418287,
            is_monoisotopic=False,
        ),
        (Element.Cd, 112): ElementInfo(
            number=48,
            symbol=Element.Cd,
            mass_number=112,
            mass=111.90276287,
            abundance=0.2413,
            average_mass=111.90276287,
            is_monoisotopic=False,
        ),
        (Element.Cd, 113): ElementInfo(
            number=48,
            symbol=Element.Cd,
            mass_number=113,
            mass=112.90440813,
            abundance=0.1222,
            average_mass=112.90440813,
            is_monoisotopic=False,
        ),
        (Element.Cd, 114): ElementInfo(
            number=48,
            symbol=Element.Cd,
            mass_number=114,
            mass=113.90336509,
            abundance=0.2873,
            average_mass=113.90336509,
            is_monoisotopic=True,
        ),
        (Element.Cd, 116): ElementInfo(
            number=48,
            symbol=Element.Cd,
            mass_number=116,
            mass=115.90476315,
            abundance=0.0749,
            average_mass=115.90476315,
            is_monoisotopic=False,
        ),
        (Element.In, None): ElementInfo(
            number=49,
            symbol=Element.In,
            mass_number=None,
            mass=114.903878776,
            abundance=None,
            average_mass=114.81808662944559,
            is_monoisotopic=None,
        ),
        (Element.In, 113): ElementInfo(
            number=49,
            symbol=Element.In,
            mass_number=113,
            mass=112.90406184,
            abundance=0.0429,
            average_mass=112.90406184,
            is_monoisotopic=False,
        ),
        (Element.In, 115): ElementInfo(
            number=49,
            symbol=Element.In,
            mass_number=115,
            mass=114.903878776,
            abundance=0.9571,
            average_mass=114.903878776,
            is_monoisotopic=True,
        ),
        (Element.Sn, None): ElementInfo(
            number=50,
            symbol=Element.Sn,
            mass_number=None,
            mass=119.90220163,
            abundance=None,
            average_mass=118.7101125930106,
            is_monoisotopic=None,
        ),
        (Element.Sn, 112): ElementInfo(
            number=50,
            symbol=Element.Sn,
            mass_number=112,
            mass=111.90482387,
            abundance=0.0097,
            average_mass=111.90482387,
            is_monoisotopic=False,
        ),
        (Element.Sn, 114): ElementInfo(
            number=50,
            symbol=Element.Sn,
            mass_number=114,
            mass=113.9027827,
            abundance=0.0066,
            average_mass=113.9027827,
            is_monoisotopic=False,
        ),
        (Element.Sn, 115): ElementInfo(
            number=50,
            symbol=Element.Sn,
            mass_number=115,
            mass=114.903344699,
            abundance=0.0034,
            average_mass=114.903344699,
            is_monoisotopic=False,
        ),
        (Element.Sn, 116): ElementInfo(
            number=50,
            symbol=Element.Sn,
            mass_number=116,
            mass=115.9017428,
            abundance=0.1454,
            average_mass=115.9017428,
            is_monoisotopic=False,
        ),
        (Element.Sn, 117): ElementInfo(
            number=50,
            symbol=Element.Sn,
            mass_number=117,
            mass=116.90295398,
            abundance=0.0768,
            average_mass=116.90295398,
            is_monoisotopic=False,
        ),
        (Element.Sn, 118): ElementInfo(
            number=50,
            symbol=Element.Sn,
            mass_number=118,
            mass=117.90160657,
            abundance=0.2422,
            average_mass=117.90160657,
            is_monoisotopic=False,
        ),
        (Element.Sn, 119): ElementInfo(
            number=50,
            symbol=Element.Sn,
            mass_number=119,
            mass=118.90331117,
            abundance=0.0859,
            average_mass=118.90331117,
            is_monoisotopic=False,
        ),
        (Element.Sn, 120): ElementInfo(
            number=50,
            symbol=Element.Sn,
            mass_number=120,
            mass=119.90220163,
            abundance=0.3258,
            average_mass=119.90220163,
            is_monoisotopic=True,
        ),
        (Element.Sn, 122): ElementInfo(
            number=50,
            symbol=Element.Sn,
            mass_number=122,
            mass=121.9034438,
            abundance=0.0463,
            average_mass=121.9034438,
            is_monoisotopic=False,
        ),
        (Element.Sn, 124): ElementInfo(
            number=50,
            symbol=Element.Sn,
            mass_number=124,
            mass=123.9052766,
            abundance=0.0579,
            average_mass=123.9052766,
            is_monoisotopic=False,
        ),
        (Element.Sb, None): ElementInfo(
            number=51,
            symbol=Element.Sb,
            mass_number=None,
            mass=120.903812,
            abundance=None,
            average_mass=121.75978367348,
            is_monoisotopic=None,
        ),
        (Element.Sb, 121): ElementInfo(
            number=51,
            symbol=Element.Sb,
            mass_number=121,
            mass=120.903812,
            abundance=0.5721,
            average_mass=120.903812,
            is_monoisotopic=True,
        ),
        (Element.Sb, 123): ElementInfo(
            number=51,
            symbol=Element.Sb,
            mass_number=123,
            mass=122.9042132,
            abundance=0.4279,
            average_mass=122.9042132,
            is_monoisotopic=False,
        ),
        (Element.Te, None): ElementInfo(
            number=52,
            symbol=Element.Te,
            mass_number=None,
            mass=129.906222748,
            abundance=None,
            average_mass=127.6031264846604,
            is_monoisotopic=None,
        ),
        (Element.Te, 120): ElementInfo(
            number=52,
            symbol=Element.Te,
            mass_number=120,
            mass=119.9040593,
            abundance=0.0009,
            average_mass=119.9040593,
            is_monoisotopic=False,
        ),
        (Element.Te, 122): ElementInfo(
            number=52,
            symbol=Element.Te,
            mass_number=122,
            mass=121.9030435,
            abundance=0.0255,
            average_mass=121.9030435,
            is_monoisotopic=False,
        ),
        (Element.Te, 123): ElementInfo(
            number=52,
            symbol=Element.Te,
            mass_number=123,
            mass=122.9042698,
            abundance=0.0089,
            average_mass=122.9042698,
            is_monoisotopic=False,
        ),
        (Element.Te, 124): ElementInfo(
            number=52,
            symbol=Element.Te,
            mass_number=124,
            mass=123.9028171,
            abundance=0.0474,
            average_mass=123.9028171,
            is_monoisotopic=False,
        ),
        (Element.Te, 125): ElementInfo(
            number=52,
            symbol=Element.Te,
            mass_number=125,
            mass=124.9044299,
            abundance=0.0707,
            average_mass=124.9044299,
            is_monoisotopic=False,
        ),
        (Element.Te, 126): ElementInfo(
            number=52,
            symbol=Element.Te,
            mass_number=126,
            mass=125.9033109,
            abundance=0.1884,
            average_mass=125.9033109,
            is_monoisotopic=False,
        ),
        (Element.Te, 128): ElementInfo(
            number=52,
            symbol=Element.Te,
            mass_number=128,
            mass=127.90446128,
            abundance=0.3174,
            average_mass=127.90446128,
            is_monoisotopic=False,
        ),
        (Element.Te, 130): ElementInfo(
            number=52,
            symbol=Element.Te,
            mass_number=130,
            mass=129.906222748,
            abundance=0.3408,
            average_mass=129.906222748,
            is_monoisotopic=True,
        ),
        (Element.I, None): ElementInfo(
            number=53,
            symbol=Element.I,
            mass_number=None,
            mass=126.9044719,
            abundance=None,
            average_mass=126.9044719,
            is_monoisotopic=None,
        ),
        (Element.I, 127): ElementInfo(
            number=53,
            symbol=Element.I,
            mass_number=127,
            mass=126.9044719,
            abundance=1.0,
            average_mass=126.9044719,
            is_monoisotopic=True,
        ),
        (Element.Xe, None): ElementInfo(
            number=54,
            symbol=Element.Xe,
            mass_number=None,
            mass=131.9041550856,
            abundance=None,
            average_mass=131.29276144779053,
            is_monoisotopic=None,
        ),
        (Element.Xe, 124): ElementInfo(
            number=54,
            symbol=Element.Xe,
            mass_number=124,
            mass=123.905892,
            abundance=0.000952,
            average_mass=123.905892,
            is_monoisotopic=False,
        ),
        (Element.Xe, 126): ElementInfo(
            number=54,
            symbol=Element.Xe,
            mass_number=126,
            mass=125.9042983,
            abundance=0.00089,
            average_mass=125.9042983,
            is_monoisotopic=False,
        ),
        (Element.Xe, 128): ElementInfo(
            number=54,
            symbol=Element.Xe,
            mass_number=128,
            mass=127.903531,
            abundance=0.019102,
            average_mass=127.903531,
            is_monoisotopic=False,
        ),
        (Element.Xe, 129): ElementInfo(
            number=54,
            symbol=Element.Xe,
            mass_number=129,
            mass=128.9047808611,
            abundance=0.264006,
            average_mass=128.9047808611,
            is_monoisotopic=False,
        ),
        (Element.Xe, 130): ElementInfo(
            number=54,
            symbol=Element.Xe,
            mass_number=130,
            mass=129.903509349,
            abundance=0.04071,
            average_mass=129.903509349,
            is_monoisotopic=False,
        ),
        (Element.Xe, 131): ElementInfo(
            number=54,
            symbol=Element.Xe,
            mass_number=131,
            mass=130.90508406,
            abundance=0.212324,
            average_mass=130.90508406,
            is_monoisotopic=False,
        ),
        (Element.Xe, 132): ElementInfo(
            number=54,
            symbol=Element.Xe,
            mass_number=132,
            mass=131.9041550856,
            abundance=0.269086,
            average_mass=131.9041550856,
            is_monoisotopic=True,
        ),
        (Element.Xe, 134): ElementInfo(
            number=54,
            symbol=Element.Xe,
            mass_number=134,
            mass=133.90539466,
            abundance=0.104357,
            average_mass=133.90539466,
            is_monoisotopic=False,
        ),
        (Element.Xe, 136): ElementInfo(
            number=54,
            symbol=Element.Xe,
            mass_number=136,
            mass=135.907214484,
            abundance=0.088573,
            average_mass=135.907214484,
            is_monoisotopic=False,
        ),
        (Element.Cs, None): ElementInfo(
            number=55,
            symbol=Element.Cs,
            mass_number=None,
            mass=132.905451961,
            abundance=None,
            average_mass=132.905451961,
            is_monoisotopic=None,
        ),
        (Element.Cs, 133): ElementInfo(
            number=55,
            symbol=Element.Cs,
            mass_number=133,
            mass=132.905451961,
            abundance=1.0,
            average_mass=132.905451961,
            is_monoisotopic=True,
        ),
        (Element.Ba, None): ElementInfo(
            number=56,
            symbol=Element.Ba,
            mass_number=None,
            mass=137.905247,
            abundance=None,
            average_mass=137.3268916286322,
            is_monoisotopic=None,
        ),
        (Element.Ba, 130): ElementInfo(
            number=56,
            symbol=Element.Ba,
            mass_number=130,
            mass=129.9063207,
            abundance=0.00106,
            average_mass=129.9063207,
            is_monoisotopic=False,
        ),
        (Element.Ba, 132): ElementInfo(
            number=56,
            symbol=Element.Ba,
            mass_number=132,
            mass=131.9050611,
            abundance=0.00101,
            average_mass=131.9050611,
            is_monoisotopic=False,
        ),
        (Element.Ba, 134): ElementInfo(
            number=56,
            symbol=Element.Ba,
            mass_number=134,
            mass=133.90450818,
            abundance=0.02417,
            average_mass=133.90450818,
            is_monoisotopic=False,
        ),
        (Element.Ba, 135): ElementInfo(
            number=56,
            symbol=Element.Ba,
            mass_number=135,
            mass=134.90568838,
            abundance=0.06592,
            average_mass=134.90568838,
            is_monoisotopic=False,
        ),
        (Element.Ba, 136): ElementInfo(
            number=56,
            symbol=Element.Ba,
            mass_number=136,
            mass=135.90457573,
            abundance=0.07854,
            average_mass=135.90457573,
            is_monoisotopic=False,
        ),
        (Element.Ba, 137): ElementInfo(
            number=56,
            symbol=Element.Ba,
            mass_number=137,
            mass=136.90582714,
            abundance=0.11232,
            average_mass=136.90582714,
            is_monoisotopic=False,
        ),
        (Element.Ba, 138): ElementInfo(
            number=56,
            symbol=Element.Ba,
            mass_number=138,
            mass=137.905247,
            abundance=0.71698,
            average_mass=137.905247,
            is_monoisotopic=True,
        ),
        (Element.La, None): ElementInfo(
            number=57,
            symbol=Element.La,
            mass_number=None,
            mass=138.9063563,
            abundance=None,
            average_mass=138.90546887371266,
            is_monoisotopic=None,
        ),
        (Element.La, 138): ElementInfo(
            number=57,
            symbol=Element.La,
            mass_number=138,
            mass=137.9071149,
            abundance=0.0008881,
            average_mass=137.9071149,
            is_monoisotopic=False,
        ),
        (Element.La, 139): ElementInfo(
            number=57,
            symbol=Element.La,
            mass_number=139,
            mass=138.9063563,
            abundance=0.9991119,
            average_mass=138.9063563,
            is_monoisotopic=True,
        ),
        (Element.Ce, None): ElementInfo(
            number=58,
            symbol=Element.Ce,
            mass_number=None,
            mass=139.9054431,
            abundance=None,
            average_mass=140.1157307378545,
            is_monoisotopic=None,
        ),
        (Element.Ce, 136): ElementInfo(
            number=58,
            symbol=Element.Ce,
            mass_number=136,
            mass=135.90712921,
            abundance=0.00185,
            average_mass=135.90712921,
            is_monoisotopic=False,
        ),
        (Element.Ce, 138): ElementInfo(
            number=58,
            symbol=Element.Ce,
            mass_number=138,
            mass=137.905991,
            abundance=0.00251,
            average_mass=137.905991,
            is_monoisotopic=False,
        ),
        (Element.Ce, 140): ElementInfo(
            number=58,
            symbol=Element.Ce,
            mass_number=140,
            mass=139.9054431,
            abundance=0.8845,
            average_mass=139.9054431,
            is_monoisotopic=True,
        ),
        (Element.Ce, 142): ElementInfo(
            number=58,
            symbol=Element.Ce,
            mass_number=142,
            mass=141.9092504,
            abundance=0.11114,
            average_mass=141.9092504,
            is_monoisotopic=False,
        ),
        (Element.Pr, None): ElementInfo(
            number=59,
            symbol=Element.Pr,
            mass_number=None,
            mass=140.9076576,
            abundance=None,
            average_mass=140.9076576,
            is_monoisotopic=None,
        ),
        (Element.Pr, 141): ElementInfo(
            number=59,
            symbol=Element.Pr,
            mass_number=141,
            mass=140.9076576,
            abundance=1.0,
            average_mass=140.9076576,
            is_monoisotopic=True,
        ),
        (Element.Nd, None): ElementInfo(
            number=60,
            symbol=Element.Nd,
            mass_number=None,
            mass=141.907729,
            abundance=None,
            average_mass=144.24159603182702,
            is_monoisotopic=None,
        ),
        (Element.Nd, 142): ElementInfo(
            number=60,
            symbol=Element.Nd,
            mass_number=142,
            mass=141.907729,
            abundance=0.27152,
            average_mass=141.907729,
            is_monoisotopic=True,
        ),
        (Element.Nd, 143): ElementInfo(
            number=60,
            symbol=Element.Nd,
            mass_number=143,
            mass=142.90982,
            abundance=0.12174,
            average_mass=142.90982,
            is_monoisotopic=False,
        ),
        (Element.Nd, 144): ElementInfo(
            number=60,
            symbol=Element.Nd,
            mass_number=144,
            mass=143.910093,
            abundance=0.23798,
            average_mass=143.910093,
            is_monoisotopic=False,
        ),
        (Element.Nd, 145): ElementInfo(
            number=60,
            symbol=Element.Nd,
            mass_number=145,
            mass=144.9125793,
            abundance=0.08293,
            average_mass=144.9125793,
            is_monoisotopic=False,
        ),
        (Element.Nd, 146): ElementInfo(
            number=60,
            symbol=Element.Nd,
            mass_number=146,
            mass=145.9131226,
            abundance=0.17189,
            average_mass=145.9131226,
            is_monoisotopic=False,
        ),
        (Element.Nd, 148): ElementInfo(
            number=60,
            symbol=Element.Nd,
            mass_number=148,
            mass=147.9168993,
            abundance=0.05756,
            average_mass=147.9168993,
            is_monoisotopic=False,
        ),
        (Element.Nd, 150): ElementInfo(
            number=60,
            symbol=Element.Nd,
            mass_number=150,
            mass=149.9209022,
            abundance=0.05638,
            average_mass=149.9209022,
            is_monoisotopic=False,
        ),
        (Element.Pm, None): ElementInfo(
            number=61,
            symbol=Element.Pm,
            mass_number=None,
            mass=144.9127559,
            abundance=None,
            average_mass=144.9127559,
            is_monoisotopic=None,
        ),
        (Element.Pm, 145): ElementInfo(
            number=61,
            symbol=Element.Pm,
            mass_number=145,
            mass=144.9127559,
            abundance=0.0,
            average_mass=144.9127559,
            is_monoisotopic=True,
        ),
        (Element.Pm, 147): ElementInfo(
            number=61,
            symbol=Element.Pm,
            mass_number=147,
            mass=146.915145,
            abundance=0.0,
            average_mass=146.915145,
            is_monoisotopic=False,
        ),
        (Element.Sm, None): ElementInfo(
            number=62,
            symbol=Element.Sm,
            mass_number=None,
            mass=151.9197397,
            abundance=None,
            average_mass=150.36635571193,
            is_monoisotopic=None,
        ),
        (Element.Sm, 144): ElementInfo(
            number=62,
            symbol=Element.Sm,
            mass_number=144,
            mass=143.9120065,
            abundance=0.0307,
            average_mass=143.9120065,
            is_monoisotopic=False,
        ),
        (Element.Sm, 147): ElementInfo(
            number=62,
            symbol=Element.Sm,
            mass_number=147,
            mass=146.9149044,
            abundance=0.1499,
            average_mass=146.9149044,
            is_monoisotopic=False,
        ),
        (Element.Sm, 148): ElementInfo(
            number=62,
            symbol=Element.Sm,
            mass_number=148,
            mass=147.9148292,
            abundance=0.1124,
            average_mass=147.9148292,
            is_monoisotopic=False,
        ),
        (Element.Sm, 149): ElementInfo(
            number=62,
            symbol=Element.Sm,
            mass_number=149,
            mass=148.9171921,
            abundance=0.1382,
            average_mass=148.9171921,
            is_monoisotopic=False,
        ),
        (Element.Sm, 150): ElementInfo(
            number=62,
            symbol=Element.Sm,
            mass_number=150,
            mass=149.9172829,
            abundance=0.0738,
            average_mass=149.9172829,
            is_monoisotopic=False,
        ),
        (Element.Sm, 152): ElementInfo(
            number=62,
            symbol=Element.Sm,
            mass_number=152,
            mass=151.9197397,
            abundance=0.2675,
            average_mass=151.9197397,
            is_monoisotopic=True,
        ),
        (Element.Sm, 154): ElementInfo(
            number=62,
            symbol=Element.Sm,
            mass_number=154,
            mass=153.9222169,
            abundance=0.2275,
            average_mass=153.9222169,
            is_monoisotopic=False,
        ),
        (Element.Eu, None): ElementInfo(
            number=63,
            symbol=Element.Eu,
            mass_number=None,
            mass=152.921238,
            abundance=None,
            average_mass=151.96437812637998,
            is_monoisotopic=None,
        ),
        (Element.Eu, 151): ElementInfo(
            number=63,
            symbol=Element.Eu,
            mass_number=151,
            mass=150.9198578,
            abundance=0.4781,
            average_mass=150.9198578,
            is_monoisotopic=False,
        ),
        (Element.Eu, 153): ElementInfo(
            number=63,
            symbol=Element.Eu,
            mass_number=153,
            mass=152.921238,
            abundance=0.5219,
            average_mass=152.921238,
            is_monoisotopic=True,
        ),
        (Element.Gd, None): ElementInfo(
            number=64,
            symbol=Element.Gd,
            mass_number=None,
            mass=157.9241123,
            abundance=None,
            average_mass=157.25213064687998,
            is_monoisotopic=None,
        ),
        (Element.Gd, 152): ElementInfo(
            number=64,
            symbol=Element.Gd,
            mass_number=152,
            mass=151.9197995,
            abundance=0.002,
            average_mass=151.9197995,
            is_monoisotopic=False,
        ),
        (Element.Gd, 154): ElementInfo(
            number=64,
            symbol=Element.Gd,
            mass_number=154,
            mass=153.9208741,
            abundance=0.0218,
            average_mass=153.9208741,
            is_monoisotopic=False,
        ),
        (Element.Gd, 155): ElementInfo(
            number=64,
            symbol=Element.Gd,
            mass_number=155,
            mass=154.9226305,
            abundance=0.148,
            average_mass=154.9226305,
            is_monoisotopic=False,
        ),
        (Element.Gd, 156): ElementInfo(
            number=64,
            symbol=Element.Gd,
            mass_number=156,
            mass=155.9221312,
            abundance=0.2047,
            average_mass=155.9221312,
            is_monoisotopic=False,
        ),
        (Element.Gd, 157): ElementInfo(
            number=64,
            symbol=Element.Gd,
            mass_number=157,
            mass=156.9239686,
            abundance=0.1565,
            average_mass=156.9239686,
            is_monoisotopic=False,
        ),
        (Element.Gd, 158): ElementInfo(
            number=64,
            symbol=Element.Gd,
            mass_number=158,
            mass=157.9241123,
            abundance=0.2484,
            average_mass=157.9241123,
            is_monoisotopic=True,
        ),
        (Element.Gd, 160): ElementInfo(
            number=64,
            symbol=Element.Gd,
            mass_number=160,
            mass=159.9270624,
            abundance=0.2186,
            average_mass=159.9270624,
            is_monoisotopic=False,
        ),
        (Element.Tb, None): ElementInfo(
            number=65,
            symbol=Element.Tb,
            mass_number=None,
            mass=158.9253547,
            abundance=None,
            average_mass=158.9253547,
            is_monoisotopic=None,
        ),
        (Element.Tb, 159): ElementInfo(
            number=65,
            symbol=Element.Tb,
            mass_number=159,
            mass=158.9253547,
            abundance=1.0,
            average_mass=158.9253547,
            is_monoisotopic=True,
        ),
        (Element.Dy, None): ElementInfo(
            number=66,
            symbol=Element.Dy,
            mass_number=None,
            mass=163.9291819,
            abundance=None,
            average_mass=162.499472819424,
            is_monoisotopic=None,
        ),
        (Element.Dy, 156): ElementInfo(
            number=66,
            symbol=Element.Dy,
            mass_number=156,
            mass=155.9242847,
            abundance=0.00056,
            average_mass=155.9242847,
            is_monoisotopic=False,
        ),
        (Element.Dy, 158): ElementInfo(
            number=66,
            symbol=Element.Dy,
            mass_number=158,
            mass=157.9244159,
            abundance=0.00095,
            average_mass=157.9244159,
            is_monoisotopic=False,
        ),
        (Element.Dy, 160): ElementInfo(
            number=66,
            symbol=Element.Dy,
            mass_number=160,
            mass=159.9252046,
            abundance=0.02329,
            average_mass=159.9252046,
            is_monoisotopic=False,
        ),
        (Element.Dy, 161): ElementInfo(
            number=66,
            symbol=Element.Dy,
            mass_number=161,
            mass=160.9269405,
            abundance=0.18889,
            average_mass=160.9269405,
            is_monoisotopic=False,
        ),
        (Element.Dy, 162): ElementInfo(
            number=66,
            symbol=Element.Dy,
            mass_number=162,
            mass=161.9268056,
            abundance=0.25475,
            average_mass=161.9268056,
            is_monoisotopic=False,
        ),
        (Element.Dy, 163): ElementInfo(
            number=66,
            symbol=Element.Dy,
            mass_number=163,
            mass=162.9287383,
            abundance=0.24896,
            average_mass=162.9287383,
            is_monoisotopic=False,
        ),
        (Element.Dy, 164): ElementInfo(
            number=66,
            symbol=Element.Dy,
            mass_number=164,
            mass=163.9291819,
            abundance=0.2826,
            average_mass=163.9291819,
            is_monoisotopic=True,
        ),
        (Element.Ho, None): ElementInfo(
            number=67,
            symbol=Element.Ho,
            mass_number=None,
            mass=164.9303288,
            abundance=None,
            average_mass=164.9303288,
            is_monoisotopic=None,
        ),
        (Element.Ho, 165): ElementInfo(
            number=67,
            symbol=Element.Ho,
            mass_number=165,
            mass=164.9303288,
            abundance=1.0,
            average_mass=164.9303288,
            is_monoisotopic=True,
        ),
        (Element.Er, None): ElementInfo(
            number=68,
            symbol=Element.Er,
            mass_number=None,
            mass=165.9302995,
            abundance=None,
            average_mass=167.259082649669,
            is_monoisotopic=None,
        ),
        (Element.Er, 162): ElementInfo(
            number=68,
            symbol=Element.Er,
            mass_number=162,
            mass=161.9287884,
            abundance=0.00139,
            average_mass=161.9287884,
            is_monoisotopic=False,
        ),
        (Element.Er, 164): ElementInfo(
            number=68,
            symbol=Element.Er,
            mass_number=164,
            mass=163.9292088,
            abundance=0.01601,
            average_mass=163.9292088,
            is_monoisotopic=False,
        ),
        (Element.Er, 166): ElementInfo(
            number=68,
            symbol=Element.Er,
            mass_number=166,
            mass=165.9302995,
            abundance=0.33503,
            average_mass=165.9302995,
            is_monoisotopic=True,
        ),
        (Element.Er, 167): ElementInfo(
            number=68,
            symbol=Element.Er,
            mass_number=167,
            mass=166.9320546,
            abundance=0.22869,
            average_mass=166.9320546,
            is_monoisotopic=False,
        ),
        (Element.Er, 168): ElementInfo(
            number=68,
            symbol=Element.Er,
            mass_number=168,
            mass=167.9323767,
            abundance=0.26978,
            average_mass=167.9323767,
            is_monoisotopic=False,
        ),
        (Element.Er, 170): ElementInfo(
            number=68,
            symbol=Element.Er,
            mass_number=170,
            mass=169.9354702,
            abundance=0.1491,
            average_mass=169.9354702,
            is_monoisotopic=False,
        ),
        (Element.Tm, None): ElementInfo(
            number=69,
            symbol=Element.Tm,
            mass_number=None,
            mass=168.9342179,
            abundance=None,
            average_mass=168.9342179,
            is_monoisotopic=None,
        ),
        (Element.Tm, 169): ElementInfo(
            number=69,
            symbol=Element.Tm,
            mass_number=169,
            mass=168.9342179,
            abundance=1.0,
            average_mass=168.9342179,
            is_monoisotopic=True,
        ),
        (Element.Yb, None): ElementInfo(
            number=70,
            symbol=Element.Yb,
            mass_number=None,
            mass=173.9388664,
            abundance=None,
            average_mass=173.05415016631704,
            is_monoisotopic=None,
        ),
        (Element.Yb, 168): ElementInfo(
            number=70,
            symbol=Element.Yb,
            mass_number=168,
            mass=167.9338896,
            abundance=0.00123,
            average_mass=167.9338896,
            is_monoisotopic=False,
        ),
        (Element.Yb, 170): ElementInfo(
            number=70,
            symbol=Element.Yb,
            mass_number=170,
            mass=169.9347664,
            abundance=0.02982,
            average_mass=169.9347664,
            is_monoisotopic=False,
        ),
        (Element.Yb, 171): ElementInfo(
            number=70,
            symbol=Element.Yb,
            mass_number=171,
            mass=170.9363302,
            abundance=0.1409,
            average_mass=170.9363302,
            is_monoisotopic=False,
        ),
        (Element.Yb, 172): ElementInfo(
            number=70,
            symbol=Element.Yb,
            mass_number=172,
            mass=171.9363859,
            abundance=0.2168,
            average_mass=171.9363859,
            is_monoisotopic=False,
        ),
        (Element.Yb, 173): ElementInfo(
            number=70,
            symbol=Element.Yb,
            mass_number=173,
            mass=172.9382151,
            abundance=0.16103,
            average_mass=172.9382151,
            is_monoisotopic=False,
        ),
        (Element.Yb, 174): ElementInfo(
            number=70,
            symbol=Element.Yb,
            mass_number=174,
            mass=173.9388664,
            abundance=0.32026,
            average_mass=173.9388664,
            is_monoisotopic=True,
        ),
        (Element.Yb, 176): ElementInfo(
            number=70,
            symbol=Element.Yb,
            mass_number=176,
            mass=175.9425764,
            abundance=0.12996,
            average_mass=175.9425764,
            is_monoisotopic=False,
        ),
        (Element.Lu, None): ElementInfo(
            number=71,
            symbol=Element.Lu,
            mass_number=None,
            mass=174.9407752,
            abundance=None,
            average_mass=174.96681495785498,
            is_monoisotopic=None,
        ),
        (Element.Lu, 175): ElementInfo(
            number=71,
            symbol=Element.Lu,
            mass_number=175,
            mass=174.9407752,
            abundance=0.97401,
            average_mass=174.9407752,
            is_monoisotopic=True,
        ),
        (Element.Lu, 176): ElementInfo(
            number=71,
            symbol=Element.Lu,
            mass_number=176,
            mass=175.9426897,
            abundance=0.02599,
            average_mass=175.9426897,
            is_monoisotopic=False,
        ),
        (Element.Hf, None): ElementInfo(
            number=72,
            symbol=Element.Hf,
            mass_number=None,
            mass=179.946557,
            abundance=None,
            average_mass=178.4849787234,
            is_monoisotopic=None,
        ),
        (Element.Hf, 174): ElementInfo(
            number=72,
            symbol=Element.Hf,
            mass_number=174,
            mass=173.9400461,
            abundance=0.0016,
            average_mass=173.9400461,
            is_monoisotopic=False,
        ),
        (Element.Hf, 176): ElementInfo(
            number=72,
            symbol=Element.Hf,
            mass_number=176,
            mass=175.9414076,
            abundance=0.0526,
            average_mass=175.9414076,
            is_monoisotopic=False,
        ),
        (Element.Hf, 177): ElementInfo(
            number=72,
            symbol=Element.Hf,
            mass_number=177,
            mass=176.9432277,
            abundance=0.186,
            average_mass=176.9432277,
            is_monoisotopic=False,
        ),
        (Element.Hf, 178): ElementInfo(
            number=72,
            symbol=Element.Hf,
            mass_number=178,
            mass=177.9437058,
            abundance=0.2728,
            average_mass=177.9437058,
            is_monoisotopic=False,
        ),
        (Element.Hf, 179): ElementInfo(
            number=72,
            symbol=Element.Hf,
            mass_number=179,
            mass=178.9458232,
            abundance=0.1362,
            average_mass=178.9458232,
            is_monoisotopic=False,
        ),
        (Element.Hf, 180): ElementInfo(
            number=72,
            symbol=Element.Hf,
            mass_number=180,
            mass=179.946557,
            abundance=0.3508,
            average_mass=179.946557,
            is_monoisotopic=True,
        ),
        (Element.Ta, None): ElementInfo(
            number=73,
            symbol=Element.Ta,
            mass_number=None,
            mass=180.9479958,
            abundance=None,
            average_mass=180.9478756362269,
            is_monoisotopic=None,
        ),
        (Element.Ta, 180): ElementInfo(
            number=73,
            symbol=Element.Ta,
            mass_number=180,
            mass=179.9474648,
            abundance=0.0001201,
            average_mass=179.9474648,
            is_monoisotopic=False,
        ),
        (Element.Ta, 181): ElementInfo(
            number=73,
            symbol=Element.Ta,
            mass_number=181,
            mass=180.9479958,
            abundance=0.9998799,
            average_mass=180.9479958,
            is_monoisotopic=True,
        ),
        (Element.W, None): ElementInfo(
            number=74,
            symbol=Element.W,
            mass_number=None,
            mass=183.95093092,
            abundance=None,
            average_mass=183.841777550513,
            is_monoisotopic=None,
        ),
        (Element.W, 180): ElementInfo(
            number=74,
            symbol=Element.W,
            mass_number=180,
            mass=179.9467108,
            abundance=0.0012,
            average_mass=179.9467108,
            is_monoisotopic=False,
        ),
        (Element.W, 182): ElementInfo(
            number=74,
            symbol=Element.W,
            mass_number=182,
            mass=181.94820394,
            abundance=0.265,
            average_mass=181.94820394,
            is_monoisotopic=False,
        ),
        (Element.W, 183): ElementInfo(
            number=74,
            symbol=Element.W,
            mass_number=183,
            mass=182.95022275,
            abundance=0.1431,
            average_mass=182.95022275,
            is_monoisotopic=False,
        ),
        (Element.W, 184): ElementInfo(
            number=74,
            symbol=Element.W,
            mass_number=184,
            mass=183.95093092,
            abundance=0.3064,
            average_mass=183.95093092,
            is_monoisotopic=True,
        ),
        (Element.W, 186): ElementInfo(
            number=74,
            symbol=Element.W,
            mass_number=186,
            mass=185.9543628,
            abundance=0.2843,
            average_mass=185.9543628,
            is_monoisotopic=False,
        ),
        (Element.Re, None): ElementInfo(
            number=75,
            symbol=Element.Re,
            mass_number=None,
            mass=186.9557501,
            abundance=None,
            average_mass=186.20670454560002,
            is_monoisotopic=None,
        ),
        (Element.Re, 185): ElementInfo(
            number=75,
            symbol=Element.Re,
            mass_number=185,
            mass=184.9529545,
            abundance=0.374,
            average_mass=184.9529545,
            is_monoisotopic=False,
        ),
        (Element.Re, 187): ElementInfo(
            number=75,
            symbol=Element.Re,
            mass_number=187,
            mass=186.9557501,
            abundance=0.626,
            average_mass=186.9557501,
            is_monoisotopic=True,
        ),
        (Element.Os, None): ElementInfo(
            number=76,
            symbol=Element.Os,
            mass_number=None,
            mass=191.961477,
            abundance=None,
            average_mass=190.22485962823998,
            is_monoisotopic=None,
        ),
        (Element.Os, 184): ElementInfo(
            number=76,
            symbol=Element.Os,
            mass_number=184,
            mass=183.9524885,
            abundance=0.0002,
            average_mass=183.9524885,
            is_monoisotopic=False,
        ),
        (Element.Os, 186): ElementInfo(
            number=76,
            symbol=Element.Os,
            mass_number=186,
            mass=185.953835,
            abundance=0.0159,
            average_mass=185.953835,
            is_monoisotopic=False,
        ),
        (Element.Os, 187): ElementInfo(
            number=76,
            symbol=Element.Os,
            mass_number=187,
            mass=186.9557474,
            abundance=0.0196,
            average_mass=186.9557474,
            is_monoisotopic=False,
        ),
        (Element.Os, 188): ElementInfo(
            number=76,
            symbol=Element.Os,
            mass_number=188,
            mass=187.9558352,
            abundance=0.1324,
            average_mass=187.9558352,
            is_monoisotopic=False,
        ),
        (Element.Os, 189): ElementInfo(
            number=76,
            symbol=Element.Os,
            mass_number=189,
            mass=188.9581442,
            abundance=0.1615,
            average_mass=188.9581442,
            is_monoisotopic=False,
        ),
        (Element.Os, 190): ElementInfo(
            number=76,
            symbol=Element.Os,
            mass_number=190,
            mass=189.9584437,
            abundance=0.2626,
            average_mass=189.9584437,
            is_monoisotopic=False,
        ),
        (Element.Os, 192): ElementInfo(
            number=76,
            symbol=Element.Os,
            mass_number=192,
            mass=191.961477,
            abundance=0.4078,
            average_mass=191.961477,
            is_monoisotopic=True,
        ),
        (Element.Ir, None): ElementInfo(
            number=77,
            symbol=Element.Ir,
            mass_number=None,
            mass=192.9629216,
            abundance=None,
            average_mass=192.2160516521,
            is_monoisotopic=None,
        ),
        (Element.Ir, 191): ElementInfo(
            number=77,
            symbol=Element.Ir,
            mass_number=191,
            mass=190.9605893,
            abundance=0.373,
            average_mass=190.9605893,
            is_monoisotopic=False,
        ),
        (Element.Ir, 193): ElementInfo(
            number=77,
            symbol=Element.Ir,
            mass_number=193,
            mass=192.9629216,
            abundance=0.627,
            average_mass=192.9629216,
            is_monoisotopic=True,
        ),
        (Element.Pt, None): ElementInfo(
            number=78,
            symbol=Element.Pt,
            mass_number=None,
            mass=194.9647917,
            abundance=None,
            average_mass=195.08445686493104,
            is_monoisotopic=None,
        ),
        (Element.Pt, 190): ElementInfo(
            number=78,
            symbol=Element.Pt,
            mass_number=190,
            mass=189.9599297,
            abundance=0.00012,
            average_mass=189.9599297,
            is_monoisotopic=False,
        ),
        (Element.Pt, 192): ElementInfo(
            number=78,
            symbol=Element.Pt,
            mass_number=192,
            mass=191.9610387,
            abundance=0.00782,
            average_mass=191.9610387,
            is_monoisotopic=False,
        ),
        (Element.Pt, 194): ElementInfo(
            number=78,
            symbol=Element.Pt,
            mass_number=194,
            mass=193.9626809,
            abundance=0.3286,
            average_mass=193.9626809,
            is_monoisotopic=False,
        ),
        (Element.Pt, 195): ElementInfo(
            number=78,
            symbol=Element.Pt,
            mass_number=195,
            mass=194.9647917,
            abundance=0.3378,
            average_mass=194.9647917,
            is_monoisotopic=True,
        ),
        (Element.Pt, 196): ElementInfo(
            number=78,
            symbol=Element.Pt,
            mass_number=196,
            mass=195.96495209,
            abundance=0.2521,
            average_mass=195.96495209,
            is_monoisotopic=False,
        ),
        (Element.Pt, 198): ElementInfo(
            number=78,
            symbol=Element.Pt,
            mass_number=198,
            mass=197.9678949,
            abundance=0.07356,
            average_mass=197.9678949,
            is_monoisotopic=False,
        ),
        (Element.Au, None): ElementInfo(
            number=79,
            symbol=Element.Au,
            mass_number=None,
            mass=196.96656879,
            abundance=None,
            average_mass=196.96656879,
            is_monoisotopic=None,
        ),
        (Element.Au, 197): ElementInfo(
            number=79,
            symbol=Element.Au,
            mass_number=197,
            mass=196.96656879,
            abundance=1.0,
            average_mass=196.96656879,
            is_monoisotopic=True,
        ),
        (Element.Hg, None): ElementInfo(
            number=80,
            symbol=Element.Hg,
            mass_number=None,
            mass=201.9706434,
            abundance=None,
            average_mass=200.59916703455602,
            is_monoisotopic=None,
        ),
        (Element.Hg, 196): ElementInfo(
            number=80,
            symbol=Element.Hg,
            mass_number=196,
            mass=195.9658326,
            abundance=0.0015,
            average_mass=195.9658326,
            is_monoisotopic=False,
        ),
        (Element.Hg, 198): ElementInfo(
            number=80,
            symbol=Element.Hg,
            mass_number=198,
            mass=197.9667686,
            abundance=0.0997,
            average_mass=197.9667686,
            is_monoisotopic=False,
        ),
        (Element.Hg, 199): ElementInfo(
            number=80,
            symbol=Element.Hg,
            mass_number=199,
            mass=198.96828064,
            abundance=0.1687,
            average_mass=198.96828064,
            is_monoisotopic=False,
        ),
        (Element.Hg, 200): ElementInfo(
            number=80,
            symbol=Element.Hg,
            mass_number=200,
            mass=199.96832659,
            abundance=0.231,
            average_mass=199.96832659,
            is_monoisotopic=False,
        ),
        (Element.Hg, 201): ElementInfo(
            number=80,
            symbol=Element.Hg,
            mass_number=201,
            mass=200.97030284,
            abundance=0.1318,
            average_mass=200.97030284,
            is_monoisotopic=False,
        ),
        (Element.Hg, 202): ElementInfo(
            number=80,
            symbol=Element.Hg,
            mass_number=202,
            mass=201.9706434,
            abundance=0.2986,
            average_mass=201.9706434,
            is_monoisotopic=True,
        ),
        (Element.Hg, 204): ElementInfo(
            number=80,
            symbol=Element.Hg,
            mass_number=204,
            mass=203.97349398,
            abundance=0.0687,
            average_mass=203.97349398,
            is_monoisotopic=False,
        ),
        (Element.Tl, None): ElementInfo(
            number=81,
            symbol=Element.Tl,
            mass_number=None,
            mass=204.9744278,
            abundance=None,
            average_mass=204.38341283936,
            is_monoisotopic=None,
        ),
        (Element.Tl, 203): ElementInfo(
            number=81,
            symbol=Element.Tl,
            mass_number=203,
            mass=202.9723446,
            abundance=0.2952,
            average_mass=202.9723446,
            is_monoisotopic=False,
        ),
        (Element.Tl, 205): ElementInfo(
            number=81,
            symbol=Element.Tl,
            mass_number=205,
            mass=204.9744278,
            abundance=0.7048,
            average_mass=204.9744278,
            is_monoisotopic=True,
        ),
        (Element.Pb, None): ElementInfo(
            number=82,
            symbol=Element.Pb,
            mass_number=None,
            mass=207.9766525,
            abundance=None,
            average_mass=207.216908063,
            is_monoisotopic=None,
        ),
        (Element.Pb, 204): ElementInfo(
            number=82,
            symbol=Element.Pb,
            mass_number=204,
            mass=203.973044,
            abundance=0.014,
            average_mass=203.973044,
            is_monoisotopic=False,
        ),
        (Element.Pb, 206): ElementInfo(
            number=82,
            symbol=Element.Pb,
            mass_number=206,
            mass=205.9744657,
            abundance=0.241,
            average_mass=205.9744657,
            is_monoisotopic=False,
        ),
        (Element.Pb, 207): ElementInfo(
            number=82,
            symbol=Element.Pb,
            mass_number=207,
            mass=206.9758973,
            abundance=0.221,
            average_mass=206.9758973,
            is_monoisotopic=False,
        ),
        (Element.Pb, 208): ElementInfo(
            number=82,
            symbol=Element.Pb,
            mass_number=208,
            mass=207.9766525,
            abundance=0.524,
            average_mass=207.9766525,
            is_monoisotopic=True,
        ),
        (Element.Bi, None): ElementInfo(
            number=83,
            symbol=Element.Bi,
            mass_number=None,
            mass=208.9803991,
            abundance=None,
            average_mass=208.9803991,
            is_monoisotopic=None,
        ),
        (Element.Bi, 209): ElementInfo(
            number=83,
            symbol=Element.Bi,
            mass_number=209,
            mass=208.9803991,
            abundance=1.0,
            average_mass=208.9803991,
            is_monoisotopic=True,
        ),
        (Element.Po, None): ElementInfo(
            number=84,
            symbol=Element.Po,
            mass_number=None,
            mass=208.9824308,
            abundance=None,
            average_mass=208.9824308,
            is_monoisotopic=None,
        ),
        (Element.Po, 209): ElementInfo(
            number=84,
            symbol=Element.Po,
            mass_number=209,
            mass=208.9824308,
            abundance=0.0,
            average_mass=208.9824308,
            is_monoisotopic=True,
        ),
        (Element.Po, 210): ElementInfo(
            number=84,
            symbol=Element.Po,
            mass_number=210,
            mass=209.9828741,
            abundance=0.0,
            average_mass=209.9828741,
            is_monoisotopic=False,
        ),
        (Element.At, None): ElementInfo(
            number=85,
            symbol=Element.At,
            mass_number=None,
            mass=209.9871479,
            abundance=None,
            average_mass=209.9871479,
            is_monoisotopic=None,
        ),
        (Element.At, 210): ElementInfo(
            number=85,
            symbol=Element.At,
            mass_number=210,
            mass=209.9871479,
            abundance=0.0,
            average_mass=209.9871479,
            is_monoisotopic=True,
        ),
        (Element.At, 211): ElementInfo(
            number=85,
            symbol=Element.At,
            mass_number=211,
            mass=210.9874966,
            abundance=0.0,
            average_mass=210.9874966,
            is_monoisotopic=False,
        ),
        (Element.Rn, None): ElementInfo(
            number=86,
            symbol=Element.Rn,
            mass_number=None,
            mass=210.9906011,
            abundance=None,
            average_mass=210.9906011,
            is_monoisotopic=None,
        ),
        (Element.Rn, 211): ElementInfo(
            number=86,
            symbol=Element.Rn,
            mass_number=211,
            mass=210.9906011,
            abundance=0.0,
            average_mass=210.9906011,
            is_monoisotopic=True,
        ),
        (Element.Rn, 220): ElementInfo(
            number=86,
            symbol=Element.Rn,
            mass_number=220,
            mass=220.0113941,
            abundance=0.0,
            average_mass=220.0113941,
            is_monoisotopic=False,
        ),
        (Element.Rn, 222): ElementInfo(
            number=86,
            symbol=Element.Rn,
            mass_number=222,
            mass=222.0175782,
            abundance=0.0,
            average_mass=222.0175782,
            is_monoisotopic=False,
        ),
        (Element.Fr, None): ElementInfo(
            number=87,
            symbol=Element.Fr,
            mass_number=None,
            mass=223.019736,
            abundance=None,
            average_mass=223.019736,
            is_monoisotopic=None,
        ),
        (Element.Fr, 223): ElementInfo(
            number=87,
            symbol=Element.Fr,
            mass_number=223,
            mass=223.019736,
            abundance=0.0,
            average_mass=223.019736,
            is_monoisotopic=True,
        ),
        (Element.Ra, None): ElementInfo(
            number=88,
            symbol=Element.Ra,
            mass_number=None,
            mass=223.0185023,
            abundance=None,
            average_mass=223.0185023,
            is_monoisotopic=None,
        ),
        (Element.Ra, 223): ElementInfo(
            number=88,
            symbol=Element.Ra,
            mass_number=223,
            mass=223.0185023,
            abundance=0.0,
            average_mass=223.0185023,
            is_monoisotopic=True,
        ),
        (Element.Ra, 224): ElementInfo(
            number=88,
            symbol=Element.Ra,
            mass_number=224,
            mass=224.020212,
            abundance=0.0,
            average_mass=224.020212,
            is_monoisotopic=False,
        ),
        (Element.Ra, 226): ElementInfo(
            number=88,
            symbol=Element.Ra,
            mass_number=226,
            mass=226.0254103,
            abundance=0.0,
            average_mass=226.0254103,
            is_monoisotopic=False,
        ),
        (Element.Ra, 228): ElementInfo(
            number=88,
            symbol=Element.Ra,
            mass_number=228,
            mass=228.0310707,
            abundance=0.0,
            average_mass=228.0310707,
            is_monoisotopic=False,
        ),
        (Element.Ac, None): ElementInfo(
            number=89,
            symbol=Element.Ac,
            mass_number=None,
            mass=227.0277523,
            abundance=None,
            average_mass=227.0277523,
            is_monoisotopic=None,
        ),
        (Element.Ac, 227): ElementInfo(
            number=89,
            symbol=Element.Ac,
            mass_number=227,
            mass=227.0277523,
            abundance=0.0,
            average_mass=227.0277523,
            is_monoisotopic=True,
        ),
        (Element.Th, None): ElementInfo(
            number=90,
            symbol=Element.Th,
            mass_number=None,
            mass=232.0380558,
            abundance=None,
            average_mass=232.0380558,
            is_monoisotopic=None,
        ),
        (Element.Th, 230): ElementInfo(
            number=90,
            symbol=Element.Th,
            mass_number=230,
            mass=230.0331341,
            abundance=0.0,
            average_mass=230.0331341,
            is_monoisotopic=False,
        ),
        (Element.Th, 232): ElementInfo(
            number=90,
            symbol=Element.Th,
            mass_number=232,
            mass=232.0380558,
            abundance=1.0,
            average_mass=232.0380558,
            is_monoisotopic=True,
        ),
        (Element.Pa, None): ElementInfo(
            number=91,
            symbol=Element.Pa,
            mass_number=None,
            mass=231.0358842,
            abundance=None,
            average_mass=231.0358842,
            is_monoisotopic=None,
        ),
        (Element.Pa, 231): ElementInfo(
            number=91,
            symbol=Element.Pa,
            mass_number=231,
            mass=231.0358842,
            abundance=1.0,
            average_mass=231.0358842,
            is_monoisotopic=True,
        ),
        (Element.U, None): ElementInfo(
            number=92,
            symbol=Element.U,
            mass_number=None,
            mass=238.0507884,
            abundance=None,
            average_mass=238.0289104616574,
            is_monoisotopic=None,
        ),
        (Element.U, 233): ElementInfo(
            number=92,
            symbol=Element.U,
            mass_number=233,
            mass=233.0396355,
            abundance=0.0,
            average_mass=233.0396355,
            is_monoisotopic=False,
        ),
        (Element.U, 234): ElementInfo(
            number=92,
            symbol=Element.U,
            mass_number=234,
            mass=234.0409523,
            abundance=5.4e-05,
            average_mass=234.0409523,
            is_monoisotopic=False,
        ),
        (Element.U, 235): ElementInfo(
            number=92,
            symbol=Element.U,
            mass_number=235,
            mass=235.0439301,
            abundance=0.007204,
            average_mass=235.0439301,
            is_monoisotopic=False,
        ),
        (Element.U, 236): ElementInfo(
            number=92,
            symbol=Element.U,
            mass_number=236,
            mass=236.0455682,
            abundance=0.0,
            average_mass=236.0455682,
            is_monoisotopic=False,
        ),
        (Element.U, 238): ElementInfo(
            number=92,
            symbol=Element.U,
            mass_number=238,
            mass=238.0507884,
            abundance=0.992742,
            average_mass=238.0507884,
            is_monoisotopic=True,
        ),
        (Element.Np, None): ElementInfo(
            number=93,
            symbol=Element.Np,
            mass_number=None,
            mass=236.04657,
            abundance=None,
            average_mass=236.04657,
            is_monoisotopic=None,
        ),
        (Element.Np, 236): ElementInfo(
            number=93,
            symbol=Element.Np,
            mass_number=236,
            mass=236.04657,
            abundance=0.0,
            average_mass=236.04657,
            is_monoisotopic=True,
        ),
        (Element.Np, 237): ElementInfo(
            number=93,
            symbol=Element.Np,
            mass_number=237,
            mass=237.0481736,
            abundance=0.0,
            average_mass=237.0481736,
            is_monoisotopic=False,
        ),
        (Element.Pu, None): ElementInfo(
            number=94,
            symbol=Element.Pu,
            mass_number=None,
            mass=238.0495601,
            abundance=None,
            average_mass=238.0495601,
            is_monoisotopic=None,
        ),
        (Element.Pu, 238): ElementInfo(
            number=94,
            symbol=Element.Pu,
            mass_number=238,
            mass=238.0495601,
            abundance=0.0,
            average_mass=238.0495601,
            is_monoisotopic=True,
        ),
        (Element.Pu, 239): ElementInfo(
            number=94,
            symbol=Element.Pu,
            mass_number=239,
            mass=239.0521636,
            abundance=0.0,
            average_mass=239.0521636,
            is_monoisotopic=False,
        ),
        (Element.Pu, 240): ElementInfo(
            number=94,
            symbol=Element.Pu,
            mass_number=240,
            mass=240.0538138,
            abundance=0.0,
            average_mass=240.0538138,
            is_monoisotopic=False,
        ),
        (Element.Pu, 241): ElementInfo(
            number=94,
            symbol=Element.Pu,
            mass_number=241,
            mass=241.0568517,
            abundance=0.0,
            average_mass=241.0568517,
            is_monoisotopic=False,
        ),
        (Element.Pu, 242): ElementInfo(
            number=94,
            symbol=Element.Pu,
            mass_number=242,
            mass=242.0587428,
            abundance=0.0,
            average_mass=242.0587428,
            is_monoisotopic=False,
        ),
        (Element.Pu, 244): ElementInfo(
            number=94,
            symbol=Element.Pu,
            mass_number=244,
            mass=244.0642053,
            abundance=0.0,
            average_mass=244.0642053,
            is_monoisotopic=False,
        ),
        (Element.Am, None): ElementInfo(
            number=95,
            symbol=Element.Am,
            mass_number=None,
            mass=241.0568293,
            abundance=None,
            average_mass=241.0568293,
            is_monoisotopic=None,
        ),
        (Element.Am, 241): ElementInfo(
            number=95,
            symbol=Element.Am,
            mass_number=241,
            mass=241.0568293,
            abundance=0.0,
            average_mass=241.0568293,
            is_monoisotopic=True,
        ),
        (Element.Am, 243): ElementInfo(
            number=95,
            symbol=Element.Am,
            mass_number=243,
            mass=243.0613813,
            abundance=0.0,
            average_mass=243.0613813,
            is_monoisotopic=False,
        ),
        (Element.Cm, None): ElementInfo(
            number=96,
            symbol=Element.Cm,
            mass_number=None,
            mass=243.0613893,
            abundance=None,
            average_mass=243.0613893,
            is_monoisotopic=None,
        ),
        (Element.Cm, 243): ElementInfo(
            number=96,
            symbol=Element.Cm,
            mass_number=243,
            mass=243.0613893,
            abundance=0.0,
            average_mass=243.0613893,
            is_monoisotopic=True,
        ),
        (Element.Cm, 244): ElementInfo(
            number=96,
            symbol=Element.Cm,
            mass_number=244,
            mass=244.0627528,
            abundance=0.0,
            average_mass=244.0627528,
            is_monoisotopic=False,
        ),
        (Element.Cm, 245): ElementInfo(
            number=96,
            symbol=Element.Cm,
            mass_number=245,
            mass=245.0654915,
            abundance=0.0,
            average_mass=245.0654915,
            is_monoisotopic=False,
        ),
        (Element.Cm, 246): ElementInfo(
            number=96,
            symbol=Element.Cm,
            mass_number=246,
            mass=246.0672238,
            abundance=0.0,
            average_mass=246.0672238,
            is_monoisotopic=False,
        ),
        (Element.Cm, 247): ElementInfo(
            number=96,
            symbol=Element.Cm,
            mass_number=247,
            mass=247.0703541,
            abundance=0.0,
            average_mass=247.0703541,
            is_monoisotopic=False,
        ),
        (Element.Cm, 248): ElementInfo(
            number=96,
            symbol=Element.Cm,
            mass_number=248,
            mass=248.0723499,
            abundance=0.0,
            average_mass=248.0723499,
            is_monoisotopic=False,
        ),
        (Element.Bk, None): ElementInfo(
            number=97,
            symbol=Element.Bk,
            mass_number=None,
            mass=247.0703073,
            abundance=None,
            average_mass=247.0703073,
            is_monoisotopic=None,
        ),
        (Element.Bk, 247): ElementInfo(
            number=97,
            symbol=Element.Bk,
            mass_number=247,
            mass=247.0703073,
            abundance=0.0,
            average_mass=247.0703073,
            is_monoisotopic=True,
        ),
        (Element.Bk, 249): ElementInfo(
            number=97,
            symbol=Element.Bk,
            mass_number=249,
            mass=249.0749877,
            abundance=0.0,
            average_mass=249.0749877,
            is_monoisotopic=False,
        ),
        (Element.Cf, None): ElementInfo(
            number=98,
            symbol=Element.Cf,
            mass_number=None,
            mass=249.0748539,
            abundance=None,
            average_mass=249.0748539,
            is_monoisotopic=None,
        ),
        (Element.Cf, 249): ElementInfo(
            number=98,
            symbol=Element.Cf,
            mass_number=249,
            mass=249.0748539,
            abundance=0.0,
            average_mass=249.0748539,
            is_monoisotopic=True,
        ),
        (Element.Cf, 250): ElementInfo(
            number=98,
            symbol=Element.Cf,
            mass_number=250,
            mass=250.0764062,
            abundance=0.0,
            average_mass=250.0764062,
            is_monoisotopic=False,
        ),
        (Element.Cf, 251): ElementInfo(
            number=98,
            symbol=Element.Cf,
            mass_number=251,
            mass=251.0795886,
            abundance=0.0,
            average_mass=251.0795886,
            is_monoisotopic=False,
        ),
        (Element.Cf, 252): ElementInfo(
            number=98,
            symbol=Element.Cf,
            mass_number=252,
            mass=252.0816272,
            abundance=0.0,
            average_mass=252.0816272,
            is_monoisotopic=False,
        ),
        (Element.Es, None): ElementInfo(
            number=99,
            symbol=Element.Es,
            mass_number=None,
            mass=252.08298,
            abundance=None,
            average_mass=252.08298,
            is_monoisotopic=None,
        ),
        (Element.Es, 252): ElementInfo(
            number=99,
            symbol=Element.Es,
            mass_number=252,
            mass=252.08298,
            abundance=0.0,
            average_mass=252.08298,
            is_monoisotopic=True,
        ),
        (Element.Fm, None): ElementInfo(
            number=100,
            symbol=Element.Fm,
            mass_number=None,
            mass=257.0951061,
            abundance=None,
            average_mass=257.0951061,
            is_monoisotopic=None,
        ),
        (Element.Fm, 257): ElementInfo(
            number=100,
            symbol=Element.Fm,
            mass_number=257,
            mass=257.0951061,
            abundance=0.0,
            average_mass=257.0951061,
            is_monoisotopic=True,
        ),
        (Element.Md, None): ElementInfo(
            number=101,
            symbol=Element.Md,
            mass_number=None,
            mass=258.0984315,
            abundance=None,
            average_mass=258.0984315,
            is_monoisotopic=None,
        ),
        (Element.Md, 258): ElementInfo(
            number=101,
            symbol=Element.Md,
            mass_number=258,
            mass=258.0984315,
            abundance=0.0,
            average_mass=258.0984315,
            is_monoisotopic=True,
        ),
        (Element.Md, 260): ElementInfo(
            number=101,
            symbol=Element.Md,
            mass_number=260,
            mass=260.10365,
            abundance=0.0,
            average_mass=260.10365,
            is_monoisotopic=False,
        ),
        (Element.No, None): ElementInfo(
            number=102,
            symbol=Element.No,
            mass_number=None,
            mass=259.10103,
            abundance=None,
            average_mass=259.10103,
            is_monoisotopic=None,
        ),
        (Element.No, 259): ElementInfo(
            number=102,
            symbol=Element.No,
            mass_number=259,
            mass=259.10103,
            abundance=0.0,
            average_mass=259.10103,
            is_monoisotopic=True,
        ),
        (Element.Lr, None): ElementInfo(
            number=103,
            symbol=Element.Lr,
            mass_number=None,
            mass=262.10961,
            abundance=None,
            average_mass=262.10961,
            is_monoisotopic=None,
        ),
        (Element.Lr, 262): ElementInfo(
            number=103,
            symbol=Element.Lr,
            mass_number=262,
            mass=262.10961,
            abundance=0.0,
            average_mass=262.10961,
            is_monoisotopic=True,
        ),
        (Element.Rf, None): ElementInfo(
            number=104,
            symbol=Element.Rf,
            mass_number=None,
            mass=267.12179,
            abundance=None,
            average_mass=267.12179,
            is_monoisotopic=None,
        ),
        (Element.Rf, 267): ElementInfo(
            number=104,
            symbol=Element.Rf,
            mass_number=267,
            mass=267.12179,
            abundance=0.0,
            average_mass=267.12179,
            is_monoisotopic=True,
        ),
        (Element.Db, None): ElementInfo(
            number=105,
            symbol=Element.Db,
            mass_number=None,
            mass=268.12567,
            abundance=None,
            average_mass=268.12567,
            is_monoisotopic=None,
        ),
        (Element.Db, 268): ElementInfo(
            number=105,
            symbol=Element.Db,
            mass_number=268,
            mass=268.12567,
            abundance=0.0,
            average_mass=268.12567,
            is_monoisotopic=True,
        ),
        (Element.Sg, None): ElementInfo(
            number=106,
            symbol=Element.Sg,
            mass_number=None,
            mass=271.13393,
            abundance=None,
            average_mass=271.13393,
            is_monoisotopic=None,
        ),
        (Element.Sg, 271): ElementInfo(
            number=106,
            symbol=Element.Sg,
            mass_number=271,
            mass=271.13393,
            abundance=0.0,
            average_mass=271.13393,
            is_monoisotopic=True,
        ),
        (Element.Bh, None): ElementInfo(
            number=107,
            symbol=Element.Bh,
            mass_number=None,
            mass=272.13826,
            abundance=None,
            average_mass=272.13826,
            is_monoisotopic=None,
        ),
        (Element.Bh, 272): ElementInfo(
            number=107,
            symbol=Element.Bh,
            mass_number=272,
            mass=272.13826,
            abundance=0.0,
            average_mass=272.13826,
            is_monoisotopic=True,
        ),
        (Element.Hs, None): ElementInfo(
            number=108,
            symbol=Element.Hs,
            mass_number=None,
            mass=270.13429,
            abundance=None,
            average_mass=270.13429,
            is_monoisotopic=None,
        ),
        (Element.Hs, 270): ElementInfo(
            number=108,
            symbol=Element.Hs,
            mass_number=270,
            mass=270.13429,
            abundance=0.0,
            average_mass=270.13429,
            is_monoisotopic=True,
        ),
        (Element.Mt, None): ElementInfo(
            number=109,
            symbol=Element.Mt,
            mass_number=None,
            mass=276.15159,
            abundance=None,
            average_mass=276.15159,
            is_monoisotopic=None,
        ),
        (Element.Mt, 276): ElementInfo(
            number=109,
            symbol=Element.Mt,
            mass_number=276,
            mass=276.15159,
            abundance=0.0,
            average_mass=276.15159,
            is_monoisotopic=True,
        ),
        (Element.Ds, None): ElementInfo(
            number=110,
            symbol=Element.Ds,
            mass_number=None,
            mass=281.16451,
            abundance=None,
            average_mass=281.16451,
            is_monoisotopic=None,
        ),
        (Element.Ds, 281): ElementInfo(
            number=110,
            symbol=Element.Ds,
            mass_number=281,
            mass=281.16451,
            abundance=0.0,
            average_mass=281.16451,
            is_monoisotopic=True,
        ),
        (Element.Rg, None): ElementInfo(
            number=111,
            symbol=Element.Rg,
            mass_number=None,
            mass=280.16514,
            abundance=None,
            average_mass=280.16514,
            is_monoisotopic=None,
        ),
        (Element.Rg, 280): ElementInfo(
            number=111,
            symbol=Element.Rg,
            mass_number=280,
            mass=280.16514,
            abundance=0.0,
            average_mass=280.16514,
            is_monoisotopic=True,
        ),
        (Element.Cn, None): ElementInfo(
            number=112,
            symbol=Element.Cn,
            mass_number=None,
            mass=285.17712,
            abundance=None,
            average_mass=285.17712,
            is_monoisotopic=None,
        ),
        (Element.Cn, 285): ElementInfo(
            number=112,
            symbol=Element.Cn,
            mass_number=285,
            mass=285.17712,
            abundance=0.0,
            average_mass=285.17712,
            is_monoisotopic=True,
        ),
        (Element.Nh, None): ElementInfo(
            number=113,
            symbol=Element.Nh,
            mass_number=None,
            mass=284.17873,
            abundance=None,
            average_mass=284.17873,
            is_monoisotopic=None,
        ),
        (Element.Nh, 284): ElementInfo(
            number=113,
            symbol=Element.Nh,
            mass_number=284,
            mass=284.17873,
            abundance=0.0,
            average_mass=284.17873,
            is_monoisotopic=True,
        ),
        (Element.Fl, None): ElementInfo(
            number=114,
            symbol=Element.Fl,
            mass_number=None,
            mass=289.19042,
            abundance=None,
            average_mass=289.19042,
            is_monoisotopic=None,
        ),
        (Element.Fl, 289): ElementInfo(
            number=114,
            symbol=Element.Fl,
            mass_number=289,
            mass=289.19042,
            abundance=0.0,
            average_mass=289.19042,
            is_monoisotopic=True,
        ),
        (Element.Mc, None): ElementInfo(
            number=115,
            symbol=Element.Mc,
            mass_number=None,
            mass=288.19274,
            abundance=None,
            average_mass=288.19274,
            is_monoisotopic=None,
        ),
        (Element.Mc, 288): ElementInfo(
            number=115,
            symbol=Element.Mc,
            mass_number=288,
            mass=288.19274,
            abundance=0.0,
            average_mass=288.19274,
            is_monoisotopic=True,
        ),
        (Element.Lv, None): ElementInfo(
            number=116,
            symbol=Element.Lv,
            mass_number=None,
            mass=293.20449,
            abundance=None,
            average_mass=293.20449,
            is_monoisotopic=None,
        ),
        (Element.Lv, 293): ElementInfo(
            number=116,
            symbol=Element.Lv,
            mass_number=293,
            mass=293.20449,
            abundance=0.0,
            average_mass=293.20449,
            is_monoisotopic=True,
        ),
        (Element.Ts, None): ElementInfo(
            number=117,
            symbol=Element.Ts,
            mass_number=None,
            mass=292.20746,
            abundance=None,
            average_mass=292.20746,
            is_monoisotopic=None,
        ),
        (Element.Ts, 292): ElementInfo(
            number=117,
            symbol=Element.Ts,
            mass_number=292,
            mass=292.20746,
            abundance=0.0,
            average_mass=292.20746,
            is_monoisotopic=True,
        ),
        (Element.Og, None): ElementInfo(
            number=118,
            symbol=Element.Og,
            mass_number=None,
            mass=294.21392,
            abundance=None,
            average_mass=294.21392,
            is_monoisotopic=None,
        ),
        (Element.Og, 294): ElementInfo(
            number=118,
            symbol=Element.Og,
            mass_number=294,
            mass=294.21392,
            abundance=0.0,
            average_mass=294.21392,
            is_monoisotopic=True,
        ),
    }

except Exception as e:
    warnings.warn(f"Exception in element_data: {e}. Using empty dictionaries.", UserWarning, stacklevel=2)
    ISOTOPES: dict[tuple[Element, int | None], ElementInfo] = {}



"""Auto-generated amino acid data with calculated masses"""
# DO NOT EDIT - generated by gen_amino_acids.py

from enum import StrEnum

from .dclass import AminoAcidInfo


class AminoAcid(StrEnum):
    """Enumeration of amino acid single-letter codes."""
    A = "A"
    B = "B"
    C = "C"
    D = "D"
    E = "E"
    F = "F"
    G = "G"
    H = "H"
    I = "I"
    J = "J"
    K = "K"
    L = "L"
    M = "M"
    N = "N"
    O = "O"
    P = "P"
    Q = "Q"
    R = "R"
    S = "S"
    T = "T"
    U = "U"
    V = "V"
    W = "W"
    X = "X"
    Y = "Y"
    Z = "Z"

    @classmethod
    def from_str(cls, aa: str) -> "AminoAcid":
        """Get AminoAcid enum from string"""
        return cls(aa.upper())


AMINO_ACID_INFOS: dict[AminoAcid, AminoAcidInfo] = {
    AminoAcid.A: AminoAcidInfo(
        id=AminoAcid.A,
        name="Alanine",
        three_letter_code="Ala",
        formula="C3H5NO",
        monoisotopic_mass=71.0371137851,
        average_mass=71.0780195962,
        dict_composition={'C': 3, 'H': 5, 'N': 1, 'O': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.B: AminoAcidInfo(
        id=AminoAcid.B,
        name="Asparagine or Aspartic acid",
        three_letter_code="Asx",
        formula=None,
        monoisotopic_mass=None,
        average_mass=None,
        dict_composition=None,
        is_mass_ambiguous=True,
        is_ambiguous=True,
    ),
    AminoAcid.C: AminoAcidInfo(
        id=AminoAcid.C,
        name="Cysteine",
        three_letter_code="Cys",
        formula="C3H5NOS",
        monoisotopic_mass=103.0091849595,
        average_mass=103.1428070024,
        dict_composition={'C': 3, 'H': 5, 'N': 1, 'O': 1, 'S': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.D: AminoAcidInfo(
        id=AminoAcid.D,
        name="Aspartic acid",
        three_letter_code="Asp",
        formula="C4H5NO3",
        monoisotopic_mass=115.0269430243,
        average_mass=115.0875653416,
        dict_composition={'C': 4, 'H': 5, 'N': 1, 'O': 3},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.E: AminoAcidInfo(
        id=AminoAcid.E,
        name="Glutamic acid",
        three_letter_code="Glu",
        formula="C5H7NO3",
        monoisotopic_mass=129.0425930888,
        average_mass=129.1141827465,
        dict_composition={'C': 5, 'H': 7, 'N': 1, 'O': 3},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.F: AminoAcidInfo(
        id=AminoAcid.F,
        name="Phenylalanine",
        three_letter_code="Phe",
        formula="C9H9NO",
        monoisotopic_mass=147.0684139141,
        average_mass=147.1741979929,
        dict_composition={'C': 9, 'H': 9, 'N': 1, 'O': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.G: AminoAcidInfo(
        id=AminoAcid.G,
        name="Glycine",
        three_letter_code="Gly",
        formula="C2H3NO",
        monoisotopic_mass=57.0214637207,
        average_mass=57.0514021914,
        dict_composition={'C': 2, 'H': 3, 'N': 1, 'O': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.H: AminoAcidInfo(
        id=AminoAcid.H,
        name="Histidine",
        three_letter_code="His",
        formula="C6H7N3O",
        monoisotopic_mass=137.0589118585,
        average_mass=137.1395152175,
        dict_composition={'C': 6, 'H': 7, 'N': 3, 'O': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.I: AminoAcidInfo(
        id=AminoAcid.I,
        name="Isoleucine",
        three_letter_code="Ile",
        formula="C6H11NO",
        monoisotopic_mass=113.0840639785,
        average_mass=113.1578718108,
        dict_composition={'C': 6, 'H': 11, 'N': 1, 'O': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.J: AminoAcidInfo(
        id=AminoAcid.J,
        name="Leucine or Isoleucine",
        three_letter_code="Xle",
        formula="C6H11NO",
        monoisotopic_mass=113.0840639785,
        average_mass=113.1578718108,
        dict_composition={'C': 6, 'H': 11, 'N': 1, 'O': 1},
        is_mass_ambiguous=False,
        is_ambiguous=True,
    ),
    AminoAcid.K: AminoAcidInfo(
        id=AminoAcid.K,
        name="Lysine",
        three_letter_code="Lys",
        formula="C6H12N2O",
        monoisotopic_mass=128.0949630152,
        average_mass=128.1725157763,
        dict_composition={'C': 6, 'H': 12, 'N': 2, 'O': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.L: AminoAcidInfo(
        id=AminoAcid.L,
        name="Leucine",
        three_letter_code="Leu",
        formula="C6H11NO",
        monoisotopic_mass=113.0840639785,
        average_mass=113.1578718108,
        dict_composition={'C': 6, 'H': 11, 'N': 1, 'O': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.M: AminoAcidInfo(
        id=AminoAcid.M,
        name="Methionine",
        three_letter_code="Met",
        formula="C5H9NOS",
        monoisotopic_mass=131.0404850885,
        average_mass=131.1960418121,
        dict_composition={'C': 5, 'H': 9, 'N': 1, 'O': 1, 'S': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.N: AminoAcidInfo(
        id=AminoAcid.N,
        name="Asparagine",
        three_letter_code="Asn",
        formula="C4H6N2O2",
        monoisotopic_mass=114.0429274414,
        average_mass=114.1028043828,
        dict_composition={'C': 4, 'H': 6, 'N': 2, 'O': 2},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.O: AminoAcidInfo(
        id=AminoAcid.O,
        name="Pyrrolysine",
        three_letter_code="Pyl",
        formula="C12H19N3O2",
        monoisotopic_mass=237.1477268648,
        average_mass=237.2986245709,
        dict_composition={'C': 12, 'H': 19, 'N': 3, 'O': 2},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.P: AminoAcidInfo(
        id=AminoAcid.P,
        name="Proline",
        three_letter_code="Pro",
        formula="C5H7NO",
        monoisotopic_mass=97.0527638496,
        average_mass=97.1153728978,
        dict_composition={'C': 5, 'H': 7, 'N': 1, 'O': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.Q: AminoAcidInfo(
        id=AminoAcid.Q,
        name="Glutamine",
        three_letter_code="Gln",
        formula="C5H8N2O2",
        monoisotopic_mass=128.0585775058,
        average_mass=128.1294217877,
        dict_composition={'C': 5, 'H': 8, 'N': 2, 'O': 2},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.R: AminoAcidInfo(
        id=AminoAcid.R,
        name="Arginine",
        three_letter_code="Arg",
        formula="C6H12N4O",
        monoisotopic_mass=156.1011110240,
        average_mass=156.1859221992,
        dict_composition={'C': 6, 'H': 12, 'N': 4, 'O': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.S: AminoAcidInfo(
        id=AminoAcid.S,
        name="Serine",
        three_letter_code="Ser",
        formula="C3H5NO2",
        monoisotopic_mass=87.0320284047,
        average_mass=87.0774245206,
        dict_composition={'C': 3, 'H': 5, 'N': 1, 'O': 2},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.T: AminoAcidInfo(
        id=AminoAcid.T,
        name="Threonine",
        three_letter_code="Thr",
        formula="C4H7NO2",
        monoisotopic_mass=101.0476784692,
        average_mass=101.1040419254,
        dict_composition={'C': 4, 'H': 7, 'N': 1, 'O': 2},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.U: AminoAcidInfo(
        id=AminoAcid.U,
        name="Selenocysteine",
        three_letter_code="Sec",
        formula="C3H5NOSe",
        monoisotopic_mass=150.9536355851,
        average_mass=150.0374081533,
        dict_composition={'C': 3, 'H': 5, 'N': 1, 'O': 1, 'Se': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.V: AminoAcidInfo(
        id=AminoAcid.V,
        name="Valine",
        three_letter_code="Val",
        formula="C5H9NO",
        monoisotopic_mass=99.0684139141,
        average_mass=99.1312544059,
        dict_composition={'C': 5, 'H': 9, 'N': 1, 'O': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.W: AminoAcidInfo(
        id=AminoAcid.W,
        name="Tryptophan",
        three_letter_code="Trp",
        formula="C11H10N2O",
        monoisotopic_mass=186.0793129507,
        average_mass=186.2103137519,
        dict_composition={'C': 11, 'H': 10, 'N': 2, 'O': 1},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.X: AminoAcidInfo(
        id=AminoAcid.X,
        name="Any amino acid",
        three_letter_code="Xaa",
        formula="",
        monoisotopic_mass=0.0000000000,
        average_mass=0.0000000000,
        dict_composition={},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.Y: AminoAcidInfo(
        id=AminoAcid.Y,
        name="Tyrosine",
        three_letter_code="Tyr",
        formula="C9H9NO2",
        monoisotopic_mass=163.0633285336,
        average_mass=163.1736029172,
        dict_composition={'C': 9, 'H': 9, 'N': 1, 'O': 2},
        is_mass_ambiguous=False,
        is_ambiguous=False,
    ),
    AminoAcid.Z: AminoAcidInfo(
        id=AminoAcid.Z,
        name="Glutamine or Glutamic acid",
        three_letter_code="Glx",
        formula=None,
        monoisotopic_mass=None,
        average_mass=None,
        dict_composition=None,
        is_mass_ambiguous=True,
        is_ambiguous=True,
    ),
}



from collections import Counter
from dataclasses import dataclass
from functools import cached_property

from ..elements import ElementInfo
from ..elements.lookup import parse_composition


@dataclass(frozen=True)
class AminoAcidInfo:
    """Information about an amino acid"""

    id: str
    name: str
    three_letter_code: str
    formula: str | None
    monoisotopic_mass: float | None
    average_mass: float | None
    dict_composition: dict[str, int] | None
    is_mass_ambiguous: bool = False  # L / I are ambiguous but not mass ambiguous
    is_ambiguous: bool = False

    @cached_property
    def composition(self) -> Counter[ElementInfo] | None:
        """Get the composition as a Counter"""
        return Counter(parse_composition(dict(self.dict_composition))) if self.dict_composition is not None else None

    @property
    def one_letter_code(self) -> str:
        return self.id

    def get_mass(self, monoisotopic: bool = True) -> float | None:
        """Get the mass of the amino acid"""
        if monoisotopic:
            return self.monoisotopic_mass
        else:
            return self.average_mass

    def to_dict(self, float_precision: int = 6) -> dict[str, object]:
        """Convert the AminoAcidInfo to a dictionary"""
        return {
            "id": self.id,
            "name": self.name,
            "three_letter_code": self.three_letter_code,
            "formula": self.formula,
            "monoisotopic_mass": round(self.monoisotopic_mass, float_precision)
            if self.monoisotopic_mass is not None
            else None,
            "average_mass": round(self.average_mass, float_precision) if self.average_mass is not None else None,
            "composition": self.dict_composition,
        }



from dataclasses import dataclass

from ..obo_entity import OboEntity


@dataclass(frozen=True, slots=True)
class ResidInfo(OboEntity):
    """Class to store information about a RESID modification"""

    @property
    def id_tag(self) -> str:
        if self.id.startswith("AA"):
            return self.id[2:].lstrip("0")
        return self.id.lstrip("0")



"""Auto-generated fragment ion data"""
# DO NOT EDIT - generated by gen_fragment_ions.py

from enum import StrEnum
from typing import Literal
from .dclass import FragmentIonInfo, IonTypeProperty


class IonType(StrEnum):
    """Fragment ion types following ProForma notation"""
    PRECURSOR = "p"
    NEUTRAL = "n"
    A = "a"
    B = "b"
    C = "c"
    X = "x"
    Y = "y"
    Z = "z"
    Z_RADICAL = "z."
    Z_PLUS_H = "z+H"
    C_MINUS_H = "c-H"
    IMMONIUM = "i"
    D = "d"
    D_VALINE = "d-valine"
    DA = "da"
    DB = "db"
    DA_THREONINE = "da-threonine"
    DA_ISOLEUCINE = "da-isoleucine"
    DB_THREONINE = "db-threonine"
    DB_ISOLEUCINE = "db-isoleucine"
    V = "v"
    W = "w"
    W_VALINE = "w-valine"
    WA_THREONINE = "wa-threonine"
    WA = "wa"
    WB = "wb"
    WA_ISOLEUCINE = "wa-isoleucine"
    WB_THREONINE = "wb-threonine"
    WB_ISOLEUCINE = "wb-isoleucine"
    BY = "by"
    AX = "ax"
    CZ = "cz"
    AY = "ay"
    AZ = "az"
    BX = "bx"
    BZ = "bz"
    CX = "cx"
    CY = "cy"


IonTypeLiteral = Literal[
    "p",
    "n",
    "a",
    "b",
    "c",
    "x",
    "y",
    "z",
    "z.",
    "z+H",
    "c-H",
    "i",
    "d",
    "d-valine",
    "da",
    "db",
    "da-threonine",
    "da-isoleucine",
    "db-threonine",
    "db-isoleucine",
    "v",
    "w",
    "w-valine",
    "wa-threonine",
    "wa",
    "wb",
    "wa-isoleucine",
    "wb-threonine",
    "wb-isoleucine",
    "by",
    "ax",
    "cz",
    "ay",
    "az",
    "bx",
    "bz",
    "cx",
    "cy",
]

ION_TYPE_DICT: dict[IonType, FragmentIonInfo] = {
IonType.PRECURSOR: FragmentIonInfo(
    id=IonType.PRECURSOR,
    name="Precursor",
    formula='H2O',
    monoisotopic_mass=18.010565,
    average_mass=18.015286,
    dict_composition={'H': 2, 'O': 1},
    properties=IonTypeProperty.INTACT,
),
IonType.NEUTRAL: FragmentIonInfo(
    id=IonType.NEUTRAL,
    name="Neutral",
    formula='',
    monoisotopic_mass=0.0,
    average_mass=0.0,
    dict_composition={},
    properties=IonTypeProperty.INTACT,
),
IonType.A: FragmentIonInfo(
    id=IonType.A,
    name="a-ion",
    formula='C-1O-1',
    monoisotopic_mass=-27.994915,
    average_mass=-28.010141,
    dict_composition={'C': -1, 'O': -1},
    properties=IonTypeProperty.FORWARD,
),
IonType.B: FragmentIonInfo(
    id=IonType.B,
    name="b-ion",
    formula='',
    monoisotopic_mass=0.0,
    average_mass=0.0,
    dict_composition={},
    properties=IonTypeProperty.FORWARD,
),
IonType.C: FragmentIonInfo(
    id=IonType.C,
    name="c-ion",
    formula='H3N',
    monoisotopic_mass=17.026549,
    average_mass=17.030525,
    dict_composition={'H': 3, 'N': 1},
    properties=IonTypeProperty.FORWARD,
),
IonType.X: FragmentIonInfo(
    id=IonType.X,
    name="x-ion",
    formula='CO2',
    monoisotopic_mass=43.989829,
    average_mass=44.009546,
    dict_composition={'C': 1, 'O': 2},
    properties=IonTypeProperty.BACKWARD,
),
IonType.Y: FragmentIonInfo(
    id=IonType.Y,
    name="y-ion",
    formula='H2O',
    monoisotopic_mass=18.010565,
    average_mass=18.015286,
    dict_composition={'H': 2, 'O': 1},
    properties=IonTypeProperty.BACKWARD,
),
IonType.Z: FragmentIonInfo(
    id=IonType.Z,
    name="z-ion",
    formula='H-1N-1O',
    monoisotopic_mass=0.984016,
    average_mass=0.984761,
    dict_composition={'H': -1, 'N': -1, 'O': 1},
    properties=IonTypeProperty.BACKWARD,
),
IonType.Z_RADICAL: FragmentIonInfo(
    id=IonType.Z_RADICAL,
    name="z• radical ion",
    formula='N-1O',
    monoisotopic_mass=1.991841,
    average_mass=1.992702,
    dict_composition={'N': -1, 'O': 1},
    properties=IonTypeProperty.BACKWARD,
),
IonType.Z_PLUS_H: FragmentIonInfo(
    id=IonType.Z_PLUS_H,
    name="z+H ion",
    formula='HN-1O',
    monoisotopic_mass=2.999666,
    average_mass=3.000642,
    dict_composition={'H': 1, 'N': -1, 'O': 1},
    properties=IonTypeProperty.BACKWARD,
),
IonType.C_MINUS_H: FragmentIonInfo(
    id=IonType.C_MINUS_H,
    name="c-H ion",
    formula='H2N',
    monoisotopic_mass=16.018724,
    average_mass=16.022585,
    dict_composition={'H': 2, 'N': 1},
    properties=IonTypeProperty.FORWARD,
),
IonType.IMMONIUM: FragmentIonInfo(
    id=IonType.IMMONIUM,
    name="Immonium",
    formula='C-1O-1',
    monoisotopic_mass=-27.994915,
    average_mass=-28.010141,
    dict_composition={'C': -1, 'O': -1},
    properties=IonTypeProperty.INTERNAL,
),
IonType.D: FragmentIonInfo(
    id=IonType.D,
    name="d-ion",
    formula='C2H3N',
    monoisotopic_mass=41.026549,
    average_mass=41.051997,
    dict_composition={'C': 2, 'H': 3, 'N': 1},
    properties=IonTypeProperty.FORWARD | IonTypeProperty.AA_SPECIFIC_FWD,
),
IonType.D_VALINE: FragmentIonInfo(
    id=IonType.D_VALINE,
    name="d-ion (valine)",
    formula='C3H6N',
    monoisotopic_mass=56.050024,
    average_mass=56.086555,
    dict_composition={'C': 3, 'H': 6, 'N': 1},
    properties=IonTypeProperty.FORWARD | IonTypeProperty.AA_SPECIFIC_FWD,
),
IonType.DA: FragmentIonInfo(
    id=IonType.DA,
    name="da-ion",
    formula=None,
    monoisotopic_mass=None,
    average_mass=None,
    dict_composition={},
    properties=IonTypeProperty.FORWARD | IonTypeProperty.AA_SPECIFIC_FWD,
),
IonType.DB: FragmentIonInfo(
    id=IonType.DB,
    name="db-ion",
    formula=None,
    monoisotopic_mass=None,
    average_mass=None,
    dict_composition={},
    properties=IonTypeProperty.FORWARD | IonTypeProperty.AA_SPECIFIC_FWD,
),
IonType.DA_THREONINE: FragmentIonInfo(
    id=IonType.DA_THREONINE,
    name="da-ion (threonine)",
    formula='C2H4NO',
    monoisotopic_mass=58.029289,
    average_mass=58.059343,
    dict_composition={'C': 2, 'H': 4, 'N': 1, 'O': 1},
    properties=IonTypeProperty.FORWARD | IonTypeProperty.AA_SPECIFIC_FWD,
),
IonType.DA_ISOLEUCINE: FragmentIonInfo(
    id=IonType.DA_ISOLEUCINE,
    name="da-ion (isoleucine)",
    formula='C4H8N',
    monoisotopic_mass=70.065674,
    average_mass=70.113173,
    dict_composition={'C': 4, 'H': 8, 'N': 1},
    properties=IonTypeProperty.FORWARD | IonTypeProperty.AA_SPECIFIC_FWD,
),
IonType.DB_THREONINE: FragmentIonInfo(
    id=IonType.DB_THREONINE,
    name="db-ion (threonine)",
    formula='C3H6N',
    monoisotopic_mass=56.050024,
    average_mass=56.086555,
    dict_composition={'C': 3, 'H': 6, 'N': 1},
    properties=IonTypeProperty.FORWARD | IonTypeProperty.AA_SPECIFIC_FWD,
),
IonType.DB_ISOLEUCINE: FragmentIonInfo(
    id=IonType.DB_ISOLEUCINE,
    name="db-ion (isoleucine)",
    formula='C3H6N',
    monoisotopic_mass=56.050024,
    average_mass=56.086555,
    dict_composition={'C': 3, 'H': 6, 'N': 1},
    properties=IonTypeProperty.FORWARD | IonTypeProperty.AA_SPECIFIC_FWD,
),
IonType.V: FragmentIonInfo(
    id=IonType.V,
    name="v-ion",
    formula='C2H2NO',
    monoisotopic_mass=56.013639,
    average_mass=56.043461,
    dict_composition={'C': 2, 'H': 2, 'N': 1, 'O': 1},
    properties=IonTypeProperty.BACKWARD | IonTypeProperty.AA_SPECIFIC_BWD,
),
IonType.W: FragmentIonInfo(
    id=IonType.W,
    name="w-ion",
    formula='C3H3O',
    monoisotopic_mass=55.01839,
    average_mass=55.055435,
    dict_composition={'C': 3, 'H': 3, 'O': 1},
    properties=IonTypeProperty.BACKWARD,
),
IonType.W_VALINE: FragmentIonInfo(
    id=IonType.W_VALINE,
    name="w-ion (valine)",
    formula='C4H6O',
    monoisotopic_mass=70.041865,
    average_mass=70.089993,
    dict_composition={'C': 4, 'H': 6, 'O': 1},
    properties=IonTypeProperty.BACKWARD | IonTypeProperty.AA_SPECIFIC_BWD,
),
IonType.WA_THREONINE: FragmentIonInfo(
    id=IonType.WA_THREONINE,
    name="wa-ion (threonine)",
    formula='C3H4O2',
    monoisotopic_mass=72.021129,
    average_mass=72.062781,
    dict_composition={'C': 3, 'H': 4, 'O': 2},
    properties=IonTypeProperty.BACKWARD | IonTypeProperty.AA_SPECIFIC_BWD,
),
IonType.WA: FragmentIonInfo(
    id=IonType.WA,
    name="wa-ion",
    formula=None,
    monoisotopic_mass=None,
    average_mass=None,
    dict_composition={},
    properties=IonTypeProperty.BACKWARD | IonTypeProperty.AA_SPECIFIC_BWD,
),
IonType.WB: FragmentIonInfo(
    id=IonType.WB,
    name="wb-ion",
    formula=None,
    monoisotopic_mass=None,
    average_mass=None,
    dict_composition={},
    properties=IonTypeProperty.BACKWARD | IonTypeProperty.AA_SPECIFIC_BWD,
),
IonType.WA_ISOLEUCINE: FragmentIonInfo(
    id=IonType.WA_ISOLEUCINE,
    name="wa-ion (isoleucine)",
    formula='C5H8O',
    monoisotopic_mass=84.057515,
    average_mass=84.11661,
    dict_composition={'C': 5, 'H': 8, 'O': 1},
    properties=IonTypeProperty.BACKWARD | IonTypeProperty.AA_SPECIFIC_BWD,
),
IonType.WB_THREONINE: FragmentIonInfo(
    id=IonType.WB_THREONINE,
    name="wb-ion (threonine)",
    formula='C4H6O',
    monoisotopic_mass=70.041865,
    average_mass=70.089993,
    dict_composition={'C': 4, 'H': 6, 'O': 1},
    properties=IonTypeProperty.BACKWARD | IonTypeProperty.AA_SPECIFIC_BWD,
),
IonType.WB_ISOLEUCINE: FragmentIonInfo(
    id=IonType.WB_ISOLEUCINE,
    name="wb-ion (isoleucine)",
    formula='C4H6O',
    monoisotopic_mass=70.041865,
    average_mass=70.089993,
    dict_composition={'C': 4, 'H': 6, 'O': 1},
    properties=IonTypeProperty.BACKWARD | IonTypeProperty.AA_SPECIFIC_BWD,
),
IonType.BY: FragmentIonInfo(
    id=IonType.BY,
    name="by internal fragment",
    formula='C-1O-1',
    monoisotopic_mass=-27.994915,
    average_mass=-28.010141,
    dict_composition={'C': -1, 'O': -1},
    properties=IonTypeProperty.INTERNAL,
),
IonType.AX: FragmentIonInfo(
    id=IonType.AX,
    name="ax internal fragment",
    formula='C-1O-1',
    monoisotopic_mass=-27.994915,
    average_mass=-28.010141,
    dict_composition={'C': -1, 'O': -1},
    properties=IonTypeProperty.INTERNAL,
),
IonType.CZ: FragmentIonInfo(
    id=IonType.CZ,
    name="cz internal fragment",
    formula='C-1O-1',
    monoisotopic_mass=-27.994915,
    average_mass=-28.010141,
    dict_composition={'C': -1, 'O': -1},
    properties=IonTypeProperty.INTERNAL,
),
IonType.AY: FragmentIonInfo(
    id=IonType.AY,
    name="ay internal fragment",
    formula='C-2O-2',
    monoisotopic_mass=-55.989829,
    average_mass=-56.020282,
    dict_composition={'C': -2, 'O': -2},
    properties=IonTypeProperty.INTERNAL,
),
IonType.AZ: FragmentIonInfo(
    id=IonType.AZ,
    name="az internal fragment",
    formula='C-2H-1N-1O-2',
    monoisotopic_mass=-71.000728,
    average_mass=-71.034926,
    dict_composition={'C': -2, 'H': -1, 'N': -1, 'O': -2},
    properties=IonTypeProperty.INTERNAL,
),
IonType.BX: FragmentIonInfo(
    id=IonType.BX,
    name="bx internal fragment",
    formula='',
    monoisotopic_mass=0.0,
    average_mass=0.0,
    dict_composition={},
    properties=IonTypeProperty.INTERNAL,
),
IonType.BZ: FragmentIonInfo(
    id=IonType.BZ,
    name="bz internal fragment",
    formula='C-1H-1N-1O-1',
    monoisotopic_mass=-43.005814,
    average_mass=-43.024785,
    dict_composition={'C': -1, 'H': -1, 'N': -1, 'O': -1},
    properties=IonTypeProperty.INTERNAL,
),
IonType.CX: FragmentIonInfo(
    id=IonType.CX,
    name="cx internal fragment",
    formula='N',
    monoisotopic_mass=14.003074,
    average_mass=14.006703,
    dict_composition={'N': 1},
    properties=IonTypeProperty.INTERNAL,
),
IonType.CY: FragmentIonInfo(
    id=IonType.CY,
    name="cy internal fragment",
    formula='C-1H-1NO-1',
    monoisotopic_mass=-14.999666,
    average_mass=-15.011378,
    dict_composition={'C': -1, 'H': -1, 'N': 1, 'O': -1},
    properties=IonTypeProperty.INTERNAL,
),
}
